@@ -552,7 +552,6 @@ get_property_value_as_string (AnjutaProperty *prop)
 	gint  int_value;
 	gchar** values;
 	gchar *text_value = NULL;
-	gchar *uri;
 	
 	if (prop->custom)
 	{
@@ -621,11 +620,6 @@ get_property_value_as_string (AnjutaProperty *prop)
 		}
 		break;
 	case ANJUTA_PROPERTY_OBJECT_TYPE_FOLDER:
-		uri = gtk_file_chooser_get_uri (
- 				GTK_FILE_CHOOSER (prop->object));
-		text_value = gnome_vfs_get_local_path_from_uri (uri);
-		g_free (uri);
-		break;
 	case ANJUTA_PROPERTY_OBJECT_TYPE_FILE:
 		text_value = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (prop->object));
 		break;
@@ -1104,7 +1098,10 @@ anjuta_preferences_register_property_raw (AnjutaPreferences *pr,
 	g_return_val_if_fail (GTK_IS_WIDGET (object), FALSE);
 	g_return_val_if_fail (key != NULL, FALSE);
 	g_return_val_if_fail (strlen(key) > 0, FALSE);
-	
+	g_return_val_if_fail ((object_type != ANJUTA_PROPERTY_OBJECT_TYPE_COMBO) ||
+				((default_value != NULL) &&
+				 (*default_value != '\0')), FALSE);
+
 	p = g_new0 (AnjutaProperty, 1);
 	g_object_ref (object);
 	p->object = object;
@@ -1654,7 +1651,7 @@ anjuta_preferences_get_dialog (AnjutaPreferences *pr)
 gboolean
 anjuta_preferences_is_dialog_created (AnjutaPreferences *pr)
 {
-	return pr->priv->prefs_dialog;
+	return (pr->priv->prefs_dialog != NULL);
 }
 
 static void anjuta_preferences_class_init    (AnjutaPreferencesClass *class);
