@@ -93,7 +93,44 @@ libanjuta_iface_cclosure_marshal_VOID__BOOLEAN_INT (GClosure     *closure,
 
 /* VOID:INT (./libanjuta-iface-marshallers.list:5) */
 
-/* VOID:INT,INT,ULONG,STRING,UINT (./libanjuta-iface-marshallers.list:6) */
+/* VOID:INT,INT (./libanjuta-iface-marshallers.list:6) */
+void
+libanjuta_iface_cclosure_marshal_VOID__INT_INT (GClosure     *closure,
+                                                GValue       *return_value G_GNUC_UNUSED,
+                                                guint         n_param_values,
+                                                const GValue *param_values,
+                                                gpointer      invocation_hint G_GNUC_UNUSED,
+                                                gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__INT_INT) (gpointer     data1,
+                                              gint         arg_1,
+                                              gint         arg_2,
+                                              gpointer     data2);
+  register GMarshalFunc_VOID__INT_INT callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 3);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__INT_INT) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_int (param_values + 1),
+            g_marshal_value_peek_int (param_values + 2),
+            data2);
+}
+
+/* VOID:INT,INT,ULONG,STRING,UINT (./libanjuta-iface-marshallers.list:7) */
 void
 libanjuta_iface_cclosure_marshal_VOID__INT_INT_ULONG_STRING_UINT (GClosure     *closure,
                                                                   GValue       *return_value G_GNUC_UNUSED,
@@ -136,9 +173,9 @@ libanjuta_iface_cclosure_marshal_VOID__INT_INT_ULONG_STRING_UINT (GClosure     *
             data2);
 }
 
-/* VOID:OBJECT (./libanjuta-iface-marshallers.list:7) */
+/* VOID:OBJECT (./libanjuta-iface-marshallers.list:8) */
 
-/* VOID:OBJECT,BOOLEAN,INT,INT,STRING (./libanjuta-iface-marshallers.list:8) */
+/* VOID:OBJECT,BOOLEAN,INT,INT,STRING (./libanjuta-iface-marshallers.list:9) */
 void
 libanjuta_iface_cclosure_marshal_VOID__OBJECT_BOOLEAN_INT_INT_STRING (GClosure     *closure,
                                                                       GValue       *return_value G_GNUC_UNUSED,
@@ -181,7 +218,7 @@ libanjuta_iface_cclosure_marshal_VOID__OBJECT_BOOLEAN_INT_INT_STRING (GClosure
             data2);
 }
 
-/* VOID:OBJECT,CHAR (./libanjuta-iface-marshallers.list:9) */
+/* VOID:OBJECT,CHAR (./libanjuta-iface-marshallers.list:10) */
 void
 libanjuta_iface_cclosure_marshal_VOID__OBJECT_CHAR (GClosure     *closure,
                                                     GValue       *return_value G_GNUC_UNUSED,
@@ -218,11 +255,11 @@ libanjuta_iface_cclosure_marshal_VOID__OBJECT_CHAR (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER (./libanjuta-iface-marshallers.list:10) */
+/* VOID:POINTER (./libanjuta-iface-marshallers.list:11) */
 
-/* VOID:STRING (./libanjuta-iface-marshallers.list:11) */
+/* VOID:STRING (./libanjuta-iface-marshallers.list:12) */
 
-/* VOID:STRING,STRING (./libanjuta-iface-marshallers.list:12) */
+/* VOID:STRING,STRING (./libanjuta-iface-marshallers.list:13) */
 void
 libanjuta_iface_cclosure_marshal_VOID__STRING_STRING (GClosure     *closure,
                                                       GValue       *return_value G_GNUC_UNUSED,
@@ -259,7 +296,7 @@ libanjuta_iface_cclosure_marshal_VOID__STRING_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:UINT,INT (./libanjuta-iface-marshallers.list:13) */
+/* VOID:UINT,INT (./libanjuta-iface-marshallers.list:14) */
 void
 libanjuta_iface_cclosure_marshal_VOID__UINT_INT (GClosure     *closure,
                                                  GValue       *return_value G_GNUC_UNUSED,
@@ -296,7 +333,7 @@ libanjuta_iface_cclosure_marshal_VOID__UINT_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:ULONG,STRING,UINT (./libanjuta-iface-marshallers.list:14) */
+/* VOID:ULONG,STRING,UINT (./libanjuta-iface-marshallers.list:15) */
 void
 libanjuta_iface_cclosure_marshal_VOID__ULONG_STRING_UINT (GClosure     *closure,
                                                           GValue       *return_value G_GNUC_UNUSED,
@@ -335,5 +372,5 @@ libanjuta_iface_cclosure_marshal_VOID__ULONG_STRING_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:VOID (./libanjuta-iface-marshallers.list:15) */
+/* VOID:VOID (./libanjuta-iface-marshallers.list:16) */
 
