@@ -27,6 +27,7 @@
 #include <libanjuta/anjuta-enum-types.h>
 #include <libanjuta/anjuta-launcher.h>
 #include <libanjuta/anjuta-marshal.h>
+#include <libanjuta/anjuta-message-area.h>
 #include <libanjuta/anjuta-plugin-description.h>
 #include <libanjuta/anjuta-plugin.h>
 #include <libanjuta/anjuta-plugin-manager.h>
@@ -42,6 +43,7 @@
 #include <libanjuta/anjuta-status.h>
 #include <libanjuta/anjuta-ui.h>
 #include <libanjuta/anjuta-utils.h>
+#include <libanjuta/anjuta-version.h>
 #include <libanjuta/resources.h>
 #include <libanjuta/anjuta-vcs-status-tree-view.h>
 #include <libanjuta/anjuta-command.h>
