@@ -17,8 +17,8 @@
  * You should have received a copy of the GNU General Public License
  * along with plugin.h.  See the file "COPYING".  If not,
  * write to:  The Free Software Foundation, Inc.,
- *            59 Temple Place - Suite 330,
- *            Boston,  MA  02111-1307, USA.
+ *            51 Franklin Street, Fifth Floor,
+ *            Boston,  MA  02110-1301, USA.
  */
 
 #ifndef _CLASS_INHERITANCE_H_
@@ -30,7 +30,7 @@
 
 G_BEGIN_DECLS
 
-extern GType class_inheritance_get_type (AnjutaGluePlugin *plugin);
+extern GType class_inheritance_get_type (GTypeModule *module);
 #define ANJUTA_TYPE_PLUGIN_CLASS_INHERITANCE         (class_inheritance_get_type (NULL))
 #define ANJUTA_PLUGIN_CLASS_INHERITANCE(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), ANJUTA_TYPE_PLUGIN_CLASS_INHERITANCE, AnjutaClassInheritance))
 #define ANJUTA_PLUGIN_CLASS_INHERITANCE_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST ((k), ANJUTA_TYPE_PLUGIN_CLASS_INHERITANCE, AnjutaClassInheritanceClass))
