@@ -36,6 +36,8 @@
 #include <libanjuta/interfaces/ianjuta-debugger-instruction.h>
 #include <libanjuta/interfaces/ianjuta-debugger-variable.h>
 
+#include <gio/gio.h>
+
 #include <stdarg.h>
 
 /* Contants defintion
@@ -56,13 +58,15 @@ typedef enum
 	INSPECT_MEMORY_COMMAND,
 	DISASSEMBLE_COMMAND,
 	LIST_REGISTER_COMMAND,
+	SET_WORKING_DIRECTORY_COMMAND,
+	SET_ENVIRONMENT_COMMAND,
 	UNLOAD_COMMAND,         /* Program loaded */
 	START_COMMAND,         
 	BREAK_LINE_COMMAND,		  /* Program loaded - Program stopped */
 	BREAK_FUNCTION_COMMAND,
-	BREAK_ADDRESS_COMMAND,
+	BREAK_ADDRESS_COMMAND,	/* 0x10 */
 	ENABLE_BREAK_COMMAND,
-	IGNORE_BREAK_COMMAND,	/* 0x10 */
+	IGNORE_BREAK_COMMAND,
 	CONDITION_BREAK_COMMAND,
 	REMOVE_BREAK_COMMAND,
 	LIST_BREAK_COMMAND,
@@ -76,9 +80,9 @@ typedef enum
 	RUN_COMMAND,		
 	RUN_TO_COMMAND,
 	STEPI_IN_COMMAND,
-	STEPI_OVER_COMMAND,
+	STEPI_OVER_COMMAND,			/* 0x20 */
 	RUN_TO_ADDRESS_COMMAND,
-	EXIT_COMMAND,				/* 0x20 */
+	EXIT_COMMAND,
 	HANDLE_SIGNAL_COMMAND,
 	LIST_LOCAL_COMMAND,
 	LIST_ARG_COMMAND,
@@ -92,9 +96,9 @@ typedef enum
 	SET_FRAME_COMMAND,
 	LIST_FRAME_COMMAND,
 	UPDATE_REGISTER_COMMAND,
-	WRITE_REGISTER_COMMAND,
+	WRITE_REGISTER_COMMAND,		/* 0x30 */
 	EVALUATE_COMMAND,
-	INSPECT_COMMAND,			/* 0x30 */
+	INSPECT_COMMAND,
 	PRINT_COMMAND,
 	CREATE_VARIABLE,
 	EVALUATE_VARIABLE,
@@ -134,6 +138,12 @@ typedef enum
 	DMA_LIST_REGISTER_COMMAND =
 		LIST_REGISTER_COMMAND |
 		NEED_DEBUGGER_STARTED | NEED_PROGRAM_LOADED | NEED_PROGRAM_STOPPED | NEED_PROGRAM_RUNNING,
+	DMA_SET_WORKING_DIRECTORY_COMMAND =
+		SET_WORKING_DIRECTORY_COMMAND |
+		NEED_DEBUGGER_STARTED | NEED_PROGRAM_LOADED,
+	DMA_SET_ENVIRONMENT_COMMAND =
+		SET_ENVIRONMENT_COMMAND |
+		NEED_DEBUGGER_STARTED | NEED_PROGRAM_LOADED,
 	DMA_UNLOAD_COMMAND =
 		UNLOAD_COMMAND | START_DEBUGGER |
 		NEED_PROGRAM_LOADED | NEED_PROGRAM_STOPPED,
@@ -341,6 +351,8 @@ struct _DmaQueueCommand
 			gchar *name;
 			gchar *value;
 		} var;
+		gchar **env;
+		gchar *dir;
 	} data;
 	struct _DmaQueueCommand *next;
 };
@@ -394,6 +406,12 @@ dma_command_new (DmaDebuggerCommand cmd_type,...)
 		break;
 	case ABORT_COMMAND:
 		break;
+	case SET_WORKING_DIRECTORY_COMMAND:
+		cmd->data.dir = g_strdup (va_arg (args, gchar *));
+		break;
+	case SET_ENVIRONMENT_COMMAND:
+		cmd->data.env = g_strdupv (va_arg (args, gchar **));
+		break;
 	case START_COMMAND:
 		cmd->data.start.args = g_strdup (va_arg (args, gchar *));
 		cmd->data.start.terminal = va_arg (args, gboolean);
@@ -606,6 +624,7 @@ dma_command_new (DmaDebuggerCommand cmd_type,...)
 		cmd->user_data = va_arg (args, gpointer);
 		break;
 	}
+	va_end (args);
 
 	return cmd;
 }
@@ -629,6 +648,18 @@ dma_queue_attach (DmaDebuggerQueue *self, pid_t pid, const GList *search_dirs)
 	return dma_debugger_queue_append (self, dma_command_new (DMA_ATTACH_COMMAND, pid, search_dirs));
 }
 
+gboolean
+dma_queue_set_working_directory(DmaDebuggerQueue *self, const gchar *directory)
+{
+	return dma_debugger_queue_append (self, dma_command_new (DMA_SET_WORKING_DIRECTORY_COMMAND, directory));
+}
+
+gboolean
+dma_queue_set_environment(DmaDebuggerQueue *self, gchar **variables)
+{
+	return dma_debugger_queue_append (self, dma_command_new (DMA_SET_ENVIRONMENT_COMMAND, variables));
+}
+
 gboolean
 dma_queue_start (DmaDebuggerQueue *self, const gchar *args, gboolean terminal, gboolean stop)
 {
@@ -1015,6 +1046,12 @@ dma_command_free (DmaQueueCommand *cmd)
         g_list_foreach (cmd->data.load.dirs, (GFunc)g_free, NULL);
         g_list_free (cmd->data.load.dirs);
 		break;
+	case SET_WORKING_DIRECTORY_COMMAND:
+		if (cmd->data.dir) g_free (cmd->data.dir);
+		break;
+	case SET_ENVIRONMENT_COMMAND:
+		g_strfreev (cmd->data.env);
+		break;
 	case ATTACH_COMMAND:
         g_list_foreach (cmd->data.attach.dirs, (GFunc)g_free, NULL);
         g_list_free (cmd->data.attach.dirs);
@@ -1099,7 +1136,7 @@ dma_command_run (DmaQueueCommand *cmd, IAnjutaDebugger *debugger,
 	gboolean ret = FALSE;
 	DmaDebuggerCommandType type = cmd->type & COMMAND_MASK;
 	IAnjutaDebuggerCallback callback = cmd->callback == NULL ? NULL : dma_debugger_queue_command_callback;
-					 
+	GFile* file;
 	switch (type)
 	{
 	case EMPTY_COMMAND:
@@ -1114,6 +1151,12 @@ dma_command_run (DmaQueueCommand *cmd, IAnjutaDebugger *debugger,
 	case ATTACH_COMMAND:
 		ret = ianjuta_debugger_attach (debugger, cmd->data.attach.pid, cmd->data.load.dirs, err);	
 		break;
+	case SET_WORKING_DIRECTORY_COMMAND:
+		ret = ianjuta_debugger_set_working_directory (debugger, cmd->data.dir, err);	
+		break;
+	case SET_ENVIRONMENT_COMMAND:
+		ret = ianjuta_debugger_set_environment (debugger, cmd->data.env, err);	
+		break;
 	case UNLOAD_COMMAND:
 	    ret = ianjuta_debugger_unload (debugger, err);
 	    break;
@@ -1130,7 +1173,9 @@ dma_command_run (DmaQueueCommand *cmd, IAnjutaDebugger *debugger,
 		ret = ianjuta_debugger_run (debugger, err);	
 		break;
 	case RUN_TO_COMMAND:
-		ret = ianjuta_debugger_run_to (debugger, cmd->data.pos.file, cmd->data.pos.line, err);	
+		file = g_file_new_for_uri (cmd->data.pos.file);
+		ret = ianjuta_debugger_run_to (debugger, file, cmd->data.pos.line, err);
+		g_object_unref (file);
 		break;
 	case STEP_IN_COMMAND:
 		ret = ianjuta_debugger_step_in (debugger, err);	
@@ -1145,10 +1190,10 @@ dma_command_run (DmaQueueCommand *cmd, IAnjutaDebugger *debugger,
 		ret = ianjuta_debugger_instruction_run_to_address (IANJUTA_DEBUGGER_INSTRUCTION (debugger), cmd->data.pos.address, err);	
 		break;
 	case STEPI_IN_COMMAND:
-		ret = ianjuta_debugger_instruction_step_in (IANJUTA_DEBUGGER_INSTRUCTION (debugger), err);	
+		ret = ianjuta_debugger_instruction_step_in_instruction (IANJUTA_DEBUGGER_INSTRUCTION (debugger), err);	
 		break;
 	case STEPI_OVER_COMMAND:
-		ret = ianjuta_debugger_instruction_step_over (IANJUTA_DEBUGGER_INSTRUCTION (debugger), err);	
+		ret = ianjuta_debugger_instruction_step_over_instruction (IANJUTA_DEBUGGER_INSTRUCTION (debugger), err);	
 		break;
 	case EXIT_COMMAND:
 		ret = ianjuta_debugger_exit (debugger, err);	
@@ -1157,18 +1202,18 @@ dma_command_run (DmaQueueCommand *cmd, IAnjutaDebugger *debugger,
 		ret = ianjuta_debugger_interrupt (debugger, err);	
 		break;
 	case ENABLE_BREAK_COMMAND:
-		ret = ianjuta_debugger_breakpoint_enable (IANJUTA_DEBUGGER_BREAKPOINT (debugger), cmd->data.brk.id, cmd->data.brk.enable, callback, queue, err);	
+		ret = ianjuta_debugger_breakpoint_enable_breakpoint (IANJUTA_DEBUGGER_BREAKPOINT (debugger), cmd->data.brk.id, cmd->data.brk.enable, callback, queue, err);	
 		break;
 	case IGNORE_BREAK_COMMAND:
-		ret = ianjuta_debugger_breakpoint_ignore (IANJUTA_DEBUGGER_BREAKPOINT (debugger), cmd->data.brk.id, cmd->data.brk.ignore, callback, queue, err);	
+		ret = ianjuta_debugger_breakpoint_ignore_breakpoint (IANJUTA_DEBUGGER_BREAKPOINT (debugger), cmd->data.brk.id, cmd->data.brk.ignore, callback, queue, err);	
 		break;
 	case REMOVE_BREAK_COMMAND:
-		ret = ianjuta_debugger_breakpoint_clear (IANJUTA_DEBUGGER_BREAKPOINT (debugger), cmd->data.brk.id, callback, queue, err);	
+		ret = ianjuta_debugger_breakpoint_clear_breakpoint (IANJUTA_DEBUGGER_BREAKPOINT (debugger), cmd->data.brk.id, callback, queue, err);	
 		break;
 	case BREAK_LINE_COMMAND:
 		if (dma_command_is_breakpoint_pending (cmd))
 		{	
-			ret = ianjuta_debugger_breakpoint_set_at_line (IANJUTA_DEBUGGER_BREAKPOINT (debugger), cmd->data.pos.file, cmd->data.pos.line, callback, queue, err);	
+			ret = ianjuta_debugger_breakpoint_set_breakpoint_at_line (IANJUTA_DEBUGGER_BREAKPOINT (debugger), cmd->data.pos.file, cmd->data.pos.line, callback, queue, err);	
 		}
 		else
 		{
@@ -1178,7 +1223,7 @@ dma_command_run (DmaQueueCommand *cmd, IAnjutaDebugger *debugger,
 	case BREAK_FUNCTION_COMMAND:
 		if (dma_command_is_breakpoint_pending (cmd))
 		{	
-			ret = ianjuta_debugger_breakpoint_set_at_function (IANJUTA_DEBUGGER_BREAKPOINT (debugger), cmd->data.pos.file, cmd->data.pos.function, callback, queue, err);	
+			ret = ianjuta_debugger_breakpoint_set_breakpoint_at_function (IANJUTA_DEBUGGER_BREAKPOINT (debugger), cmd->data.pos.file, cmd->data.pos.function, callback, queue, err);	
 		}
 		else
 		{
@@ -1188,7 +1233,7 @@ dma_command_run (DmaQueueCommand *cmd, IAnjutaDebugger *debugger,
 	case BREAK_ADDRESS_COMMAND:
 		if (dma_command_is_breakpoint_pending (cmd))
 		{	
-			ret = ianjuta_debugger_breakpoint_set_at_address (IANJUTA_DEBUGGER_BREAKPOINT (debugger), cmd->data.pos.address, callback, queue, err);	
+			ret = ianjuta_debugger_breakpoint_set_breakpoint_at_address (IANJUTA_DEBUGGER_BREAKPOINT (debugger), cmd->data.pos.address, callback, queue, err);	
 		}
 		else
 		{
@@ -1196,10 +1241,10 @@ dma_command_run (DmaQueueCommand *cmd, IAnjutaDebugger *debugger,
 		}
 		break;
 	case CONDITION_BREAK_COMMAND:
-		ret = ianjuta_debugger_breakpoint_condition (IANJUTA_DEBUGGER_BREAKPOINT (debugger), cmd->data.brk.id, cmd->data.brk.condition, callback, queue, err);	
+		ret = ianjuta_debugger_breakpoint_condition_breakpoint (IANJUTA_DEBUGGER_BREAKPOINT (debugger), cmd->data.brk.id, cmd->data.brk.condition, callback, queue, err);	
 		break;
 	case LIST_BREAK_COMMAND:
-		ret = ianjuta_debugger_breakpoint_list (IANJUTA_DEBUGGER_BREAKPOINT (debugger), callback, queue, err);	
+		ret = ianjuta_debugger_breakpoint_list_breakpoint (IANJUTA_DEBUGGER_BREAKPOINT (debugger), callback, queue, err);	
 		break;
 	case INSPECT_COMMAND:
 		ret = ianjuta_debugger_inspect (debugger, cmd->data.watch.name, callback, queue, err);
@@ -1253,16 +1298,16 @@ dma_command_run (DmaQueueCommand *cmd, IAnjutaDebugger *debugger,
 		ret = ianjuta_debugger_list_frame (debugger, callback, queue, err);	
 		break;
 	case LIST_REGISTER_COMMAND:
-		ret = ianjuta_debugger_register_list (IANJUTA_DEBUGGER_REGISTER (debugger), callback, queue, err);	
+		ret = ianjuta_debugger_register_list_register (IANJUTA_DEBUGGER_REGISTER (debugger), callback, queue, err);	
 		break;
 	case UPDATE_REGISTER_COMMAND:
-		ret = ianjuta_debugger_register_update (IANJUTA_DEBUGGER_REGISTER (debugger), callback, queue, err);	
+		ret = ianjuta_debugger_register_update_register (IANJUTA_DEBUGGER_REGISTER (debugger), callback, queue, err);	
 		break;
 	case WRITE_REGISTER_COMMAND:
 		reg.num = cmd->data.watch.id;
 	    reg.name = cmd->data.watch.name;
 	    reg.value = cmd->data.watch.value;
-		ret = ianjuta_debugger_register_write (IANJUTA_DEBUGGER_REGISTER (debugger), &reg, err);	
+		ret = ianjuta_debugger_register_write_register (IANJUTA_DEBUGGER_REGISTER (debugger), &reg, err);	
 		break;
 	case INSPECT_MEMORY_COMMAND:
 		ret = ianjuta_debugger_memory_inspect (IANJUTA_DEBUGGER_MEMORY (debugger), cmd->data.mem.address, cmd->data.mem.length, callback, queue, err);	
@@ -1316,6 +1361,8 @@ dma_command_callback (DmaQueueCommand *cmd, const gpointer data, GError *err)
 	case QUIT_COMMAND:
 	case ABORT_COMMAND:
 	case START_COMMAND:
+	case SET_WORKING_DIRECTORY_COMMAND:
+	case SET_ENVIRONMENT_COMMAND:	
 	case RUN_COMMAND:
 	case RUN_TO_COMMAND:
 	case STEP_IN_COMMAND:
