@@ -45,8 +45,6 @@
 #include <libgnomevfs/gnome-vfs-mime-utils.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 
-#include <gnome.h>
-
 #include <glade/glade-xml.h>
 
 #include <errno.h>
@@ -244,6 +242,7 @@ on_session_save (AnjutaShell *shell, AnjutaSessionPhase phase, AnjutaSession *se
 	if (phase != ANJUTA_SESSION_PHASE_NORMAL)
 		return;
 
+	anjuta_session_set_string_list (session, "Debugger", "Source directories", self->source_dirs);
 	anjuta_session_set_int (session, "Debugger", "Stop at beginning", self->stop_at_beginning + 1);
 }
 
@@ -254,6 +253,14 @@ static void on_session_load (AnjutaShell *shell, AnjutaSessionPhase phase, Anjut
 	if (phase != ANJUTA_SESSION_PHASE_NORMAL)
 		return;
 
+	/* Initialize source_dirs */
+ 	if (self->source_dirs != NULL)
+	{		
+ 		g_list_foreach (self->source_dirs, (GFunc)g_free, NULL);
+ 		g_list_free (self->source_dirs);
+ 	}
+ 	self->source_dirs = anjuta_session_get_string_list (session, "Debugger", "Source directories");
+
 	stop_at_beginning = anjuta_session_get_int (session, "Debugger", "Stop at beginning");
 	if (stop_at_beginning == 0)
 		self->stop_at_beginning = TRUE;	/* Default value */
@@ -585,7 +592,7 @@ attach_process_update (AttachProcess * ap)
 #else
 	cmd = g_strconcat ("ps axw -H -o pid,user,start_time,args > ", tmp, NULL);
 #endif
-	shell = gnome_util_user_shell ();
+	shell = anjuta_util_user_shell ();
 	ch_pid = fork ();
 	if (ch_pid == 0)
 	{
@@ -877,7 +884,7 @@ load_target (DmaStart *this, const gchar *target)
 }
 
 static void
-on_build_finished (GObject *builder, GError *err, gpointer user_data)
+on_build_finished (GObject *builder, IAnjutaBuilderHandle handle, GError *err, gpointer user_data)
 {
 	DmaStart *this = (DmaStart *)user_data;
 	
@@ -892,7 +899,7 @@ on_build_finished (GObject *builder, GError *err, gpointer user_data)
 }
 
 static void
-on_is_built_finished (GObject *builder, GError *err, gpointer user_data)
+on_is_built_finished (GObject *builder, IAnjutaBuilderHandle handle, GError *err, gpointer user_data)
 {
 	DmaStart *this = (DmaStart *)user_data;
 	
