@@ -18,7 +18,6 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 #include <config.h>
-#include <libgnomevfs/gnome-vfs-ops.h>
 #include <libanjuta/anjuta-ui.h>
 #include <libanjuta/anjuta-utils.h>
 
@@ -38,8 +37,6 @@
 #include <libanjuta/interfaces/ianjuta-editor-goto.h>
 #include <libanjuta/interfaces/ianjuta-editor-language.h>
 
-#include <libegg/menu/egg-entry-action.h>
-
 #include <sys/wait.h>
 #include <sys/stat.h>
 
@@ -187,12 +184,20 @@ on_close_file_activate (GtkAction *action, gpointer user_data)
 	{
 		GtkWidget *parent;
 		gchar *uri;
+		GFile* file;
 		AnjutaSavePrompt *save_prompt;
 		
 		parent = gtk_widget_get_toplevel (GTK_WIDGET (doc));
 		/* Prompt for unsaved data */
 		save_prompt = anjuta_save_prompt_new (GTK_WINDOW (parent));
-		uri = ianjuta_file_get_uri (IANJUTA_FILE (doc), NULL);
+		file = ianjuta_file_get_file (IANJUTA_FILE (doc), NULL);
+		if (file)
+		{
+			uri = g_file_get_uri (file);
+			g_object_unref (file);
+		}
+		else
+			uri = NULL;
 		/* NULL uri ok */
 		anjuta_save_prompt_add_item (save_prompt,
 									 ianjuta_document_get_filename (doc, NULL),
@@ -251,17 +256,6 @@ on_close_all_file_activate (GtkAction *action, gpointer user_data)
 	}
 }
 
-void
-on_new_file_activate (GtkAction *action, gpointer user_data)
-{
-	AnjutaDocman *docman;
-	DocmanPlugin *plugin;
-	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
-	docman = ANJUTA_DOCMAN (plugin->docman);
-
-	anjuta_docman_add_editor (docman, NULL, NULL);
-}
-
 void
 on_reload_file_activate (GtkAction *action, gpointer user_data)
 {
@@ -292,13 +286,12 @@ on_reload_file_activate (GtkAction *action, gpointer user_data)
 									 GTK_RESPONSE_NO);
 	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_YES)
 	{
-		gchar* uri;
-		uri = ianjuta_file_get_uri (IANJUTA_FILE (doc), NULL);
-		if (uri)
+		GFile* file;
+		file = ianjuta_file_get_file (IANJUTA_FILE (doc), NULL);
+		if (file)
 		{
-			ianjuta_file_open (IANJUTA_FILE (doc), uri, NULL);
-			/* FIXME: anjuta_update_title (); */
-			g_free (uri);
+			ianjuta_file_open (IANJUTA_FILE (doc), file, NULL);
+			g_object_unref(file);
 		}
 	}
 	gtk_widget_destroy (dialog);
@@ -514,6 +507,7 @@ on_editor_command_paste_activate (GtkAction *action, gpointer user_data)
 	{
 		gtk_editable_paste_clipboard (GTK_EDITABLE (widget));
 	}
+	else
 	{
 		if (widget	/* editor text is focused */
 			|| get_current_popup_active (user_data))
@@ -888,134 +882,6 @@ on_force_hilite_activate (GtkWidget *menuitem, gpointer user_data)
 	}
 }
 
-/* Gets the swapped (c/h) file names */
-static gchar*
-get_swapped_filename (const gchar* filename)
-{
-	size_t len;
-	gchar *newfname;
-	GnomeVFSURI *vfs_uri;
-
-	g_return_val_if_fail (filename != NULL, NULL);
-
-	len = strlen (filename);
-	newfname = g_malloc (len+5); /* to be on the safer side */
-	while (len)
-	{
-		if (filename[len] == '.')
-			break;
-		len--;
-	}
-	len++;
-	strcpy (newfname, filename);
-	if (strncasecmp (&filename[len], "h", 1) == 0)
-	{
-		strcpy (&newfname[len], "cc");
-		vfs_uri = gnome_vfs_uri_new (newfname);
-		if (gnome_vfs_uri_exists (vfs_uri))
-		{
-			gnome_vfs_uri_unref (vfs_uri);
-			return newfname;
-		}
-		gnome_vfs_uri_unref (vfs_uri);
-		
-		strcpy (&newfname[len], "cpp");
-		vfs_uri = gnome_vfs_uri_new (newfname);
-		if (gnome_vfs_uri_exists (vfs_uri))
-		{
-			gnome_vfs_uri_unref (vfs_uri);
-			return newfname;
-		}
-		gnome_vfs_uri_unref (vfs_uri);
-		
-		strcpy (&newfname[len], "cxx");
-		vfs_uri = gnome_vfs_uri_new (newfname);
-		if (gnome_vfs_uri_exists (vfs_uri))
-		{
-			gnome_vfs_uri_unref (vfs_uri);
-			return newfname;
-		}
-		gnome_vfs_uri_unref (vfs_uri);
-		
-		strcpy (&newfname[len], "c");
-		vfs_uri = gnome_vfs_uri_new (newfname);
-		if (gnome_vfs_uri_exists (vfs_uri))
-		{ 
-			gnome_vfs_uri_unref (vfs_uri);
-			return newfname;
-		}
-		gnome_vfs_uri_unref (vfs_uri);
-	}
-	else if (strncasecmp (&filename[len], "c", 1)==0 )
-	{
-		strcpy (&newfname[len], "h");
-		vfs_uri = gnome_vfs_uri_new (newfname);
-		if (gnome_vfs_uri_exists (vfs_uri))
-		{ 
-			gnome_vfs_uri_unref (vfs_uri);
-			return newfname;
-		}
-		gnome_vfs_uri_unref (vfs_uri);
-		
-		strcpy (&newfname[len], "hh");
-		vfs_uri = gnome_vfs_uri_new (newfname);
-		if (gnome_vfs_uri_exists (vfs_uri))
-		{
-			gnome_vfs_uri_unref (vfs_uri);
-			return newfname;
-		}
-		gnome_vfs_uri_unref (vfs_uri);
-		
-		strcpy (&newfname[len], "hxx");
-		vfs_uri = gnome_vfs_uri_new (newfname);
-		if (gnome_vfs_uri_exists (vfs_uri))
-		{
-			gnome_vfs_uri_unref (vfs_uri);
-			return newfname;
-		}
-		gnome_vfs_uri_unref (vfs_uri);
-		
-		strcpy (&newfname[len], "hpp");
-		vfs_uri = gnome_vfs_uri_new (newfname);
-		if (gnome_vfs_uri_exists (vfs_uri))
-		{
-			gnome_vfs_uri_unref (vfs_uri);
-			return newfname;
-		}
-		gnome_vfs_uri_unref (vfs_uri);
-	}
-	g_free (newfname);	
-	return NULL;
-}
-
-void
-on_swap_activate (GtkAction *action, gpointer user_data)
-{
-	IAnjutaDocument *doc;
-	AnjutaDocman *docman;
-	DocmanPlugin *plugin;
-
-	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
-	docman = ANJUTA_DOCMAN (plugin->docman);
-	doc = anjuta_docman_get_current_document (docman);
-	if (doc)
-	{
-		gchar *uri;
-		uri = ianjuta_file_get_uri (IANJUTA_FILE (doc), NULL);
-		if (uri)
-		{
-			gchar *newfname;
-			newfname = get_swapped_filename (uri);
-			g_free (uri);
-			if (newfname)
-			{
-				anjuta_docman_goto_file_line (docman, newfname, -1);
-				g_free (newfname);
-			}
-		}
-	}
-}
-
 void
 on_show_search (GtkAction *action, gpointer user_data)
 {
@@ -1066,3 +932,25 @@ on_editor_remove_view_activate (GtkAction *action, gpointer user_data)
 	if (doc)
 		ianjuta_editor_view_remove_current (IANJUTA_EDITOR_VIEW (doc), NULL);
 }
+
+void on_next_document (GtkAction *action, gpointer user_data)
+{
+	AnjutaDocman *docman;
+	DocmanPlugin *plugin;
+	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
+	docman = ANJUTA_DOCMAN (plugin->docman);
+	
+	gtk_notebook_set_current_page (GTK_NOTEBOOK (docman),
+								   gtk_notebook_get_current_page (GTK_NOTEBOOK(docman)) + 1);
+}
+
+void on_previous_document (GtkAction *action, gpointer user_data)
+{
+	AnjutaDocman *docman;
+	DocmanPlugin *plugin;
+	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
+	docman = ANJUTA_DOCMAN (plugin->docman);
+	
+	gtk_notebook_set_current_page (GTK_NOTEBOOK (docman),
+								   gtk_notebook_get_current_page (GTK_NOTEBOOK(docman)) - 1);
+}
