@@ -19,13 +19,12 @@
 */
 
 #include <config.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
 #include <libanjuta/anjuta-shell.h>
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/anjuta-encodings.h>
 
-#include <libegg/menu/egg-entry-action.h>
 #include <libanjuta/interfaces/ianjuta-document-manager.h>
+#include <libanjuta/interfaces/ianjuta-project-manager.h>
 #include <libanjuta/interfaces/ianjuta-file.h>
 #include <libanjuta/interfaces/ianjuta-editor.h>
 #include <libanjuta/interfaces/ianjuta-editor-selection.h>
@@ -54,8 +53,6 @@
 #define PREFS_GLADE PACKAGE_DATA_DIR"/glade/anjuta-document-manager.glade"
 #define ICON_FILE "anjuta-document-manager-plugin-48.png"
 
-/* Pixmaps */
-#define ANJUTA_PIXMAP_SWAP                "anjuta-swap"
 #define ANJUTA_PIXMAP_BOOKMARK_TOGGLE     "anjuta-bookmark-toggle"
 #define ANJUTA_PIXMAP_BOOKMARK_FIRST      "anjuta-bookmark-first"
 #define ANJUTA_PIXMAP_BOOKMARK_PREV       "anjuta-bookmark-prev"
@@ -81,7 +78,6 @@
 
 
 /* Stock icons */
-#define ANJUTA_STOCK_SWAP                     "anjuta-swap"
 #define ANJUTA_STOCK_FOLD_TOGGLE              "anjuta-fold-toggle"
 #define ANJUTA_STOCK_FOLD_OPEN                "anjuta-fold-open"
 #define ANJUTA_STOCK_FOLD_CLOSE               "anjuta-fold-close"
@@ -151,9 +147,6 @@ static ShortcutMapping global_keymap[] = {
 };
 
 static GtkActionEntry actions_file[] = {
-  { "ActionFileNew", GTK_STOCK_NEW, N_("_New"), "<control>n",
-	N_("New empty file"),
-    G_CALLBACK (on_new_file_activate)},
   { "ActionFileSave", GTK_STOCK_SAVE, N_("_Save"), "<control>s",
 	N_("Save current file"), G_CALLBACK (on_save_activate)},
   { "ActionFileSaveAs", GTK_STOCK_SAVE_AS, N_("Save _As..."),  "<shift><control>s",
@@ -171,9 +164,6 @@ static GtkActionEntry actions_file[] = {
   { "ActionFileReload", GTK_STOCK_REVERT_TO_SAVED, N_("Reload F_ile"), NULL,
 	N_("Reload current file"),
     G_CALLBACK (on_reload_file_activate)},
-  { "ActionFileSwap", ANJUTA_STOCK_SWAP, N_("Swap .h/.c"), NULL,
-	N_("Swap c header and source files"),
-    G_CALLBACK (on_swap_activate)},
   { "ActionMenuFileRecentFiles", NULL, N_("Recent _Files"),  NULL, NULL, NULL},	/* menu title */
 };
 
@@ -397,6 +387,16 @@ static GtkActionEntry actions_bookmark[] = {
     G_CALLBACK (on_editor_command_bookmark_clear_activate)},
 };
 
+static GtkActionEntry actions_documents[] = {
+  {"ActionMenuDocuments", NULL, N_("_Documents"), NULL, NULL, NULL},
+  { "ActionDocumentsPrevious", GTK_STOCK_GO_BACK, N_("Previous Document"),
+	"<control><alt>Page_Up", N_("Switch to previous document"),
+    G_CALLBACK (on_previous_document)},
+  { "ActionDocumentsNext", GTK_STOCK_GO_FORWARD, N_("Next Document"),
+	"<control><alt>Page_Down", N_("Switch to next document"),
+    G_CALLBACK (on_next_document)},
+};
+
 struct ActionGroupInfo {
 	GtkActionEntry *group;
 	gint size;
@@ -424,7 +424,8 @@ static struct ActionGroupInfo action_groups[] = {
 	{ actions_style, G_N_ELEMENTS (actions_style), "ActionGroupEditorStyle", N_("Editor syntax highlighting styles") },
 	{ actions_format, G_N_ELEMENTS (actions_format), "ActionGroupEditorFormat", N_("Editor text formating") },
 	{ actions_bookmark, G_N_ELEMENTS (actions_bookmark), "ActionGroupEditorBookmark", N_("Editor bookmarks") },
-	{ actions_search, G_N_ELEMENTS (actions_search), "ActionGroupEditorSearch", N_("Simple searching") }
+	{ actions_search, G_N_ELEMENTS (actions_search), "ActionGroupEditorSearch", N_("Simple searching") },
+	{ actions_documents, G_N_ELEMENTS (actions_documents), "ActionGroupDocuments", N_("Documents") }
 };
 
 static struct ActionToggleGroupInfo action_toggle_groups[] = {
@@ -442,60 +443,84 @@ static struct ActionToggleGroupInfo action_toggle_groups[] = {
 #define VIEW_EOL                   "view.eol"
 #define VIEW_LINE_WRAP             "view.line.wrap"
 
+#define MAX_TITLE_LENGTH 80
+
+static gchar* 
+get_directory_display_name (DocmanPlugin* plugin,
+							GFile* file)
+{
+	gchar* dir;
+	gchar* display_uri = g_file_get_parse_name (file);
+	gchar* display_dir;
+	dir = anjuta_util_uri_get_dirname (display_uri);
+	
+	display_dir = anjuta_util_str_middle_truncate (dir, 
+												   MAX (20, MAX_TITLE_LENGTH));	
+	g_free (display_uri);
+	g_free (dir);
+	return display_dir;
+}
+
 static void
 update_title (DocmanPlugin* doc_plugin)
 {
 	IAnjutaDocument *doc;
 	AnjutaStatus *status;
-	gchar *filename;
 	gchar *title;
 
 	doc = anjuta_docman_get_current_document (ANJUTA_DOCMAN (doc_plugin->docman));
 
 	if (doc)
 	{
-		gchar *uri;
-		uri = ianjuta_file_get_uri (IANJUTA_FILE (doc), NULL);
-		if (uri)
+		gchar* real_filename;
+		gchar *dir;
+		const gchar *filename;
+		filename = ianjuta_document_get_filename (doc, NULL);
+		GFile* file;
+		file = ianjuta_file_get_file (IANJUTA_FILE (doc), NULL);
+		if (file)
 		{
-			filename = gnome_vfs_get_local_path_from_uri (uri);
-			g_free (uri);
+			dir = get_directory_display_name (doc_plugin, file);
+			g_object_unref (file);
 		}
 		else
-			filename = NULL;
+		{
+			dir = NULL;
+		}
+		if (ianjuta_file_savable_is_dirty(IANJUTA_FILE_SAVABLE (doc), NULL))
+		{
+			gchar* dirty_name = g_strconcat ("*", filename, NULL);
+			real_filename = dirty_name;
+		}
+		else
+			real_filename = g_strdup (filename);
+		
+		if (doc_plugin->project_name)
+		{
+			if (dir)
+				title = g_strdup_printf ("%s (%s) - %s", real_filename, dir, 
+										 doc_plugin->project_name);
+			else
+				title = g_strdup_printf ("%s - %s", real_filename, 
+										 doc_plugin->project_name);				
+		}
+		else
+		{
+			if (dir)
+				title = g_strdup_printf ("%s (%s)", real_filename, dir);
+			else
+				title = g_strdup_printf ("%s (%s)", real_filename, dir);				
+		}
+		g_free (real_filename);
+		g_free (dir);
 	}
 	else
-		filename = NULL;
-	if (filename && doc_plugin->project_name)
-	{
-		gchar *display_filename = NULL;
-		if (doc_plugin->project_path)
-		{
-			if (g_str_has_prefix (filename, doc_plugin->project_path))
-			{
-				/* the +1 is the '/' */
-				display_filename = filename + strlen (doc_plugin->project_path) + 1;
-			}
-		}
-		if (!display_filename)
-			display_filename = filename;
-		title = g_strconcat (doc_plugin->project_name, " - ", display_filename, NULL);
-	}
-	else if (filename)
-	{
-		title = g_strdup (filename);
-	}
-	else if (doc_plugin->project_name)
 	{
 		title = g_strdup (doc_plugin->project_name);
 	}
-	else
-		title = NULL;
-	
 	status = anjuta_shell_get_status (ANJUTA_PLUGIN (doc_plugin)->shell, NULL);
 	/* NULL title is ok */
 	anjuta_status_set_title (status, title);
-	g_free (filename);
 	g_free (title);
 }
 
@@ -518,16 +543,17 @@ value_added_project_root_uri (AnjutaPlugin *plugin, const gchar *name,
 	root_uri = g_value_get_string (value);
 	if (root_uri)
 	{
-		gchar* path = 
-			gnome_vfs_get_local_path_from_uri (root_uri);
+		GFile* file = g_file_new_for_uri (root_uri);
+		gchar* path = g_file_get_path (file);
 		
-		doc_plugin->project_name = g_path_get_basename(path);
+		doc_plugin->project_name = g_file_get_basename (file);
 		doc_plugin->project_path = path; 
 		
 		if (doc_plugin->project_name)
 		{
 			update_title (doc_plugin);
 		}
+		g_object_unref (file);
 	}
 }
 
@@ -582,10 +608,6 @@ ui_give_shorter_names (AnjutaPlugin *plugin)
 	GtkAction *action;
 			
 	ui = anjuta_shell_get_ui (ANJUTA_PLUGIN (plugin)->shell, NULL);
-	action = anjuta_ui_get_action (ui, "ActionGroupEditorFile",
-									"ActionFileNew");
-	g_object_set (G_OBJECT (action), "short-label", _("New"),
-				  "is-important", TRUE, NULL);
 	action = anjuta_ui_get_action (ui, "ActionGroupEditorFile",
 								   "ActionFileSave");
 	g_object_set (G_OBJECT (action), "short-label", _("Save"),
@@ -637,10 +659,8 @@ update_document_ui_disable_all (AnjutaPlugin *plugin)
 		{
 			action = anjuta_ui_get_action (ui, action_groups[i].name,
 										   action_groups[i].group[j].name);
-			if (action_groups[i].group[j].callback &&
-				strcmp (action_groups[i].group[j].name, "ActionFileNew") != 0)
+			if (action_groups[i].group[j].callback)
 			{
-				/* Disable all but ActoinFileNew actions */
 				g_object_set (G_OBJECT (action), "sensitive", FALSE, NULL);
 			}
 		}
@@ -696,23 +716,6 @@ update_document_ui_interface_items (AnjutaPlugin *plugin, IAnjutaDocument *doc)
 	action = anjuta_ui_get_action (ui, "ActionGroupEditorStyle",
 								   "ActionMenuFormatStyle");
 	g_object_set (G_OBJECT (action), "visible", flag, "sensitive", flag, NULL);
-	
-	if (flag)
-	{
-		IAnjutaLanguage *language;
-		language = anjuta_shell_get_interface (plugin->shell, IAnjutaLanguage, NULL);
-		if (language)
-		{
-			/* Check if it is a C or C++ file */
-			const gchar *lang_name =
-				ianjuta_language_get_name_from_editor (language, IANJUTA_EDITOR_LANGUAGE (doc), NULL);
-			flag = (lang_name && (g_str_equal (lang_name, "C") || g_str_equal (lang_name, "C++")));
-		}
-	}
-
-	action = anjuta_ui_get_action (ui, "ActionGroupEditorFile",
-								   "ActionFileSwap");
-	g_object_set (G_OBJECT (action), "sensitive", flag, NULL);
 
 	/* IAnjutaDocument */
 	flag = IANJUTA_IS_DOCUMENT (doc);
@@ -863,6 +866,7 @@ on_document_update_save_ui (IAnjutaDocument *doc, gboolean entered,
 							AnjutaPlugin *plugin)
 {
 	update_document_ui_save_items (plugin, doc);
+	update_title(ANJUTA_PLUGIN_DOCMAN (plugin));
 }
 
 static void
@@ -876,7 +880,6 @@ register_stock_icons (AnjutaPlugin *plugin)
 	/* Register stock icons */
 	BEGIN_REGISTER_ICON (plugin);
 	REGISTER_ICON (ICON_FILE, "editor-plugin-icon");
-	REGISTER_ICON_FULL (ANJUTA_PIXMAP_SWAP, ANJUTA_STOCK_SWAP);
 	REGISTER_ICON_FULL (ANJUTA_PIXMAP_FOLD_TOGGLE, ANJUTA_STOCK_FOLD_TOGGLE);
 	REGISTER_ICON_FULL (ANJUTA_PIXMAP_FOLD_OPEN, ANJUTA_STOCK_FOLD_OPEN);
 	REGISTER_ICON_FULL (ANJUTA_PIXMAP_FOLD_CLOSE, ANJUTA_STOCK_FOLD_CLOSE);
@@ -973,7 +976,7 @@ on_document_update_ui (IAnjutaDocument *doc, DocmanPlugin *plugin)
 	IAnjutaDocument *curdoc;
 		
 	curdoc = anjuta_docman_get_current_document (ANJUTA_DOCMAN (plugin->docman));
-	update_document_ui_undo_items (plugin, curdoc);
+	update_document_ui_undo_items (ANJUTA_PLUGIN(plugin), curdoc);
 
 	if (IANJUTA_IS_EDITOR (curdoc) && curdoc == doc)
 	{
@@ -1168,13 +1171,13 @@ on_document_changed (AnjutaDocman *docman, IAnjutaDocument *doc,
 		g_value_init (&value, G_TYPE_OBJECT);
 		g_value_set_object (&value, doc);
 		anjuta_shell_add_value (plugin->shell,
-								"document_manager_current_editor",
+								IANJUTA_DOCUMENT_MANAGER_CURRENT_DOCUMENT,
 								&value, NULL);
 		g_value_unset(&value);
 	}
 	else
 	{
-		anjuta_shell_remove_value (plugin->shell, "document_manager_current_editor",
+		anjuta_shell_remove_value (plugin->shell, IANJUTA_DOCUMENT_MANAGER_CURRENT_DOCUMENT,
 								   NULL);
 	}
 
@@ -1379,8 +1382,6 @@ on_session_save (AnjutaShell *shell, AnjutaSessionPhase phase,
 		return;
 
 	files = anjuta_session_get_string_list (session, "File Loader", "Files"); /* probably NULL */
-	if (files)
-		files = g_list_reverse (files);
 	/* buffers list is ordered last-opened to first-opened */
 	docwids = anjuta_docman_get_all_doc_widgets (ANJUTA_DOCMAN (plugin->docman));
 	if (docwids)
@@ -1391,18 +1392,19 @@ on_session_save (AnjutaShell *shell, AnjutaSessionPhase phase,
 			if (IANJUTA_IS_EDITOR (node->data))
 			{
 				IAnjutaEditor *te;
-				gchar *te_uri;
+				GFile* file;
 
 				te = IANJUTA_EDITOR (node->data);
-				te_uri = ianjuta_file_get_uri (IANJUTA_FILE (te), NULL);
-				if (te_uri)
+				file = ianjuta_file_get_file (IANJUTA_FILE (te), NULL);
+				if (file)
 				{
 					gchar *uri;
+					gchar* file_uri = g_file_get_uri (file);
 					/* Save line locations also */
-					uri = g_strdup_printf ("%s#%d", te_uri,
+					uri = g_strdup_printf ("%s#%d", file_uri,
 										  ianjuta_editor_get_lineno (te, NULL));
 					files = g_list_prepend (files, uri);
-					g_free (te_uri);
+					g_free (file_uri);
 				}
 			}
 		}
@@ -1410,7 +1412,6 @@ on_session_save (AnjutaShell *shell, AnjutaSessionPhase phase,
 	}
 	if (files)
 	{
-		files = g_list_reverse (files);
 		anjuta_session_set_string_list (session, "File Loader", "Files", files);
 		g_list_foreach (files, (GFunc)g_free, NULL);
 		g_list_free (files);
@@ -1445,12 +1446,15 @@ on_save_prompt (AnjutaShell *shell, AnjutaSavePrompt *save_prompt,
 			{
 				const gchar *name;
 				gchar *uri;
+				GFile* file;
 			
 				name = ianjuta_document_get_filename (IANJUTA_DOCUMENT (editor), NULL);
-				uri = ianjuta_file_get_uri (IANJUTA_FILE (editor), NULL);
+				file = ianjuta_file_get_file (IANJUTA_FILE (editor), NULL);
+				uri = g_file_get_uri (file);
 				anjuta_save_prompt_add_item (save_prompt, name, uri, editor,
 											 on_save_prompt_save_editor, plugin);
 				g_free (uri);
+				g_object_unref (file);
 			}
 		}
 		g_list_free (buffers);
@@ -1532,13 +1536,12 @@ on_docman_auto_save (gpointer data)
 			doc = IANJUTA_DOCUMENT (node->data);
 			if (ianjuta_file_savable_is_dirty (IANJUTA_FILE_SAVABLE (doc), NULL))
 			{
-				gchar *uri;
-				uri = ianjuta_file_get_uri (IANJUTA_FILE (doc), NULL);
-				if (uri)
+				GFile* file = ianjuta_file_get_file (IANJUTA_FILE (doc), NULL);
+				if (file)
 				{
 					GError *err = NULL;
+					g_object_unref (file);
 
-					g_free (uri);
 					ianjuta_file_savable_save (IANJUTA_FILE_SAVABLE (doc), &err);
 					if (err)
 					{
@@ -1732,7 +1735,8 @@ activate_plugin (AnjutaPlugin *plugin)
 							 "AnjutaDocumentManager", _("Documents"),
 							 "editor-plugin-icon", 
 							 ANJUTA_SHELL_PLACEMENT_CENTER, 
-							 TRUE, NULL); 
+							 TRUE, NULL);
+	anjuta_shell_present_widget (plugin->shell, dplugin->vbox, NULL); 
 		
 	ui_states_init(plugin);
 	ui_give_shorter_names (plugin);
@@ -1759,7 +1763,7 @@ activate_plugin (AnjutaPlugin *plugin)
 					  G_CALLBACK (on_save_prompt), plugin);
 	
 	dplugin->project_watch_id =
-		anjuta_plugin_add_watch (plugin, "project_root_uri",
+		anjuta_plugin_add_watch (plugin, IANJUTA_PROJECT_MANAGER_PROJECT_ROOT_URI,
 								 value_added_project_root_uri,
 								 value_removed_project_root_uri, NULL);
 	dplugin->project_name = NULL;
@@ -1832,7 +1836,14 @@ static void
 dispose (GObject *obj)
 {
 	// DocmanPlugin *eplugin = ANJUTA_PLUGIN_DOCMAN (obj);
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, dispose, (obj));
+	G_OBJECT_CLASS (parent_class)->dispose (obj);
+}
+
+static void
+finalize (GObject *obj)
+{
+	/* Finalization codes here */
+	G_OBJECT_CLASS (parent_class)->finalize (obj);
 }
 
 static void
@@ -1855,25 +1866,26 @@ docman_plugin_class_init (GObjectClass *klass)
 	plugin_class->activate = activate_plugin;
 	plugin_class->deactivate = deactivate_plugin;
 	klass->dispose = dispose;
+	klass->finalize = finalize;
 }
 
 /* Implement IAnjutaDocumentManager interfaces */
-static gchar*
-ianjuta_docman_get_uri (IAnjutaDocumentManager *plugin,
+static GFile*
+ianjuta_docman_get_file (IAnjutaDocumentManager *plugin,
 		const gchar *filename, GError **e)
 {
 	AnjutaDocman *docman;
 	docman = ANJUTA_DOCMAN ((ANJUTA_PLUGIN_DOCMAN (plugin)->docman));
-	return anjuta_docman_get_uri (docman, filename);
+	return anjuta_docman_get_file (docman, filename);
 }
 
 static IAnjutaDocument*
-ianjuta_docman_get_document_for_uri (IAnjutaDocumentManager *plugin,
-		const gchar *file_uri, GError **e)
+ianjuta_docman_get_document_for_file (IAnjutaDocumentManager *plugin,
+		GFile* file, GError **e)
 {
 	AnjutaDocman *docman;
 	docman = ANJUTA_DOCMAN ((ANJUTA_PLUGIN_DOCMAN (plugin)->docman));
-	return anjuta_docman_get_document_for_uri (docman, file_uri);
+	return anjuta_docman_get_document_for_file (docman, file);
 }
 
 static IAnjutaDocument*
@@ -1893,6 +1905,17 @@ ianjuta_docman_set_current_document (IAnjutaDocumentManager *plugin,
 	anjuta_docman_set_current_document (docman, doc);
 }
 
+static void
+ianjuta_docman_set_message_area (IAnjutaDocumentManager *plugin,
+								 IAnjutaDocument *doc,
+								 GtkWidget *message_area,
+								 GError **e)
+{
+	AnjutaDocman *docman;
+	docman = ANJUTA_DOCMAN ((ANJUTA_PLUGIN_DOCMAN (plugin)->docman));
+	anjuta_docman_set_message_area (docman, doc, message_area);
+}
+
 static GList*
 ianjuta_docman_get_doc_widgets (IAnjutaDocumentManager *plugin, GError **e)
 {
@@ -1902,21 +1925,21 @@ ianjuta_docman_get_doc_widgets (IAnjutaDocumentManager *plugin, GError **e)
 }
 
 static IAnjutaEditor*
-ianjuta_docman_goto_uri_line (IAnjutaDocumentManager *plugin,
-							   const gchar *uri, gint linenum, GError **e)
+ianjuta_docman_goto_file_line (IAnjutaDocumentManager *plugin,
+							   GFile* file, gint linenum, GError **e)
 {
 	AnjutaDocman *docman;
 	docman = ANJUTA_DOCMAN ((ANJUTA_PLUGIN_DOCMAN (plugin)->docman));
-	return anjuta_docman_goto_uri_line (docman, uri, linenum);
+	return anjuta_docman_goto_file_line (docman, file, linenum);
 }
 
 static IAnjutaEditor*
-ianjuta_docman_goto_uri_line_mark (IAnjutaDocumentManager *plugin,
-		const gchar *uri, gint linenum, gboolean mark, GError **e)
+ianjuta_docman_goto_file_line_mark (IAnjutaDocumentManager *plugin,
+		GFile* file, gint linenum, gboolean mark, GError **e)
 {
 	AnjutaDocman *docman;
 	docman = ANJUTA_DOCMAN ((ANJUTA_PLUGIN_DOCMAN (plugin)->docman));
-	return anjuta_docman_goto_uri_line_mark (docman, uri, linenum, mark);
+	return anjuta_docman_goto_file_line_mark (docman, file, linenum, mark);
 }
 
 /**
@@ -1930,7 +1953,7 @@ ianjuta_docman_goto_uri_line_mark (IAnjutaDocumentManager *plugin,
  */
 static IAnjutaEditor*
 ianjuta_docman_add_buffer (IAnjutaDocumentManager *plugin,
-						   const gchar *filename, const gchar *content,
+						   const gchar* filename, const gchar *content,
 						   GError **e)
 {
 	AnjutaDocman *docman;
@@ -1987,28 +2010,29 @@ ianjuta_document_manager_iface_init (IAnjutaDocumentManagerIface *iface)
 {
 	iface->add_buffer = ianjuta_docman_add_buffer;
 	iface->add_document = ianjuta_docman_add_document;
-	iface->find_document_with_uri = ianjuta_docman_get_document_for_uri;
+	iface->find_document_with_file = ianjuta_docman_get_document_for_file;
 	iface->get_current_document = ianjuta_docman_get_current_document;
 	iface->get_doc_widgets = ianjuta_docman_get_doc_widgets;
-	iface->get_uri = ianjuta_docman_get_uri;
-	iface->goto_uri_line = ianjuta_docman_goto_uri_line;
-	iface->goto_uri_line_mark = ianjuta_docman_goto_uri_line_mark;
+	iface->get_file = ianjuta_docman_get_file;
+	iface->goto_file_line = ianjuta_docman_goto_file_line;
+	iface->goto_file_line_mark = ianjuta_docman_goto_file_line_mark;
 	iface->remove_document = ianjuta_docman_remove_document;
 	iface->set_current_document = ianjuta_docman_set_current_document;
+	iface->set_message_area = ianjuta_docman_set_message_area;
 }
 
 /* Implement IAnjutaFile interface */
 static void
-ifile_open (IAnjutaFile* plugin, const gchar* uri, GError** e)
+ifile_open (IAnjutaFile* plugin, GFile* file, GError** e)
 {
 	AnjutaDocman *docman;
 	
 	docman = ANJUTA_DOCMAN ((ANJUTA_PLUGIN_DOCMAN (plugin)->docman));
-	anjuta_docman_goto_uri_line_mark (docman, uri, -1, FALSE);
+	anjuta_docman_goto_file_line (docman, file, -1);
 }
 
-static gchar*
-ifile_get_uri (IAnjutaFile* plugin, GError** e)
+static GFile*
+ifile_get_file (IAnjutaFile* plugin, GError** e)
 {
 	AnjutaDocman *docman;
 	IAnjutaDocument *doc;
@@ -2016,11 +2040,7 @@ ifile_get_uri (IAnjutaFile* plugin, GError** e)
 	docman = ANJUTA_DOCMAN ((ANJUTA_PLUGIN_DOCMAN (plugin)->docman));
 	doc = anjuta_docman_get_current_document (docman);
 	if (doc != NULL)
-		return ianjuta_file_get_uri (IANJUTA_FILE (doc), NULL);
-/* bad to call this func with NULL arg
-	else if (ianjuta_document_get_filename (doc, NULL))
-		return gnome_vfs_get_uri_from_local_path (ianjuta_document_get_filename(editor, NULL));
-*/
+		return ianjuta_file_get_file (IANJUTA_FILE (doc), NULL);
 	else
 		return NULL;
 }
@@ -2029,7 +2049,7 @@ static void
 ifile_iface_init (IAnjutaFileIface *iface)
 {
 	iface->open = ifile_open;
-	iface->get_uri = ifile_get_uri;
+	iface->get_file = ifile_get_file;
 }
 
 /* Implement IAnjutaFileSavable interface */	
@@ -2060,7 +2080,7 @@ isaveable_save (IAnjutaFileSavable* plugin, GError** e)
 }
 
 static void
-isavable_save_as (IAnjutaFileSavable* plugin, const gchar* uri, GError** e)
+isavable_save_as (IAnjutaFileSavable* plugin, GFile* file, GError** e)
 {
 	DEBUG_PRINT("save_as: Not implemented in DocmanPlugin");
 }
@@ -2118,7 +2138,6 @@ ipreferences_merge(IAnjutaPreferences* ipref, AnjutaPreferences* prefs, GError**
 		
 	anjuta_preferences_add_page (prefs,
 									gxml, "Documents", _("Documents"),  ICON_FILE);
-	anjuta_encodings_init (prefs, gxml);
 				
 	g_object_unref (G_OBJECT (gxml));
 }
