@@ -80,7 +80,7 @@ typedef struct _NewfileType
 
 NewfileType new_file_type[] = {
 	{N_("C Source File"), ".c", TRUE, TRUE, FALSE, CMT_C, LGE_C},
-	{N_("C -C++ Header File"), ".h", TRUE, TRUE, TRUE, CMT_C, LGE_HC},
+	{N_("C/C++ Header File"), ".h", TRUE, TRUE, TRUE, CMT_C, LGE_HC},
 	{N_("C++ Source File"), ".cxx", TRUE, TRUE, FALSE, CMT_CPP, LGE_CPLUS},
 	{N_("C# Source File"), ".c#", TRUE, FALSE, FALSE, CMT_CPP, LGE_CSHARP},
 	{N_("Java Source File"), ".java", TRUE, TRUE, FALSE, CMT_CPP, LGE_JAVA},
@@ -288,6 +288,7 @@ on_new_file_okbutton_clicked(GtkWidget *window, GdkEvent *event,
 		IAnjutaProjectManager *pm;
 		GnomeVFSHandle *vfs_write;
 		gchar* file_uri;
+		GFile* file;
 		
 		pm = anjuta_shell_get_interface (ANJUTA_PLUGIN(docman)->shell, 
 										 IAnjutaProjectManager, NULL);
@@ -306,8 +307,10 @@ on_new_file_okbutton_clicked(GtkWidget *window, GdkEvent *event,
 			g_free (file_uri);
 			return FALSE;
 		}
-		ianjuta_file_open (IANJUTA_FILE (docman), file_uri, NULL);
+		file = g_file_new_for_uri (file_uri);
+		ianjuta_file_open (IANJUTA_FILE (docman), file, NULL);
 		g_free (file_uri);
+		g_object_unref (file);
 	}
 	else
 	{
