@@ -24,7 +24,9 @@
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/interfaces/ianjuta-iterable.h>
 #include <libanjuta/interfaces/ianjuta-document.h>
+#include <libanjuta/interfaces/ianjuta-document-manager.h>
 #include <libanjuta/interfaces/ianjuta-editor.h>
+#include <libanjuta/interfaces/ianjuta-file.h>
 #include <libanjuta/interfaces/ianjuta-editor-cell.h>
 #include <libanjuta/interfaces/ianjuta-editor-language.h>
 #include <libanjuta/interfaces/ianjuta-editor-selection.h>
@@ -36,9 +38,12 @@
 #include "plugin.h"
 #include "cpp-java-utils.h"
 
+/* Pixmaps */
+#define ANJUTA_PIXMAP_SWAP                "anjuta-swap"
 #define ANJUTA_PIXMAP_COMPLETE			  "anjuta-complete"
 #define ANJUTA_PIXMAP_AUTOCOMPLETE        "anjuta-complete-auto"
 #define ANJUTA_PIXMAP_AUTOINDENT          "anjuta-indent-auto"
+#define ANJUTA_STOCK_SWAP                     "anjuta-swap"
 #define ANJUTA_STOCK_COMPLETE         	  "anjuta-complete"
 #define ANJUTA_STOCK_AUTOCOMPLETE         "anjuta-autocomplete"
 #define ANJUTA_STOCK_AUTOINDENT           "anjuta-indent"
@@ -54,6 +59,7 @@
 #define PREF_INDENT_TAB_INDENTS "language.cpp.indent.tab.indents"
 #define PREF_INDENT_STATEMENT_SIZE "language.cpp.indent.statement.size"
 #define PREF_INDENT_BRACE_SIZE "language.cpp.indent.brace.size"
+#define PREF_BRACE_AUTOCOMPLETION "language.cpp.brace.autocompletion"
 
 #define TAB_SIZE (ianjuta_editor_get_tabsize (editor, NULL))
 
@@ -411,7 +417,7 @@ static void
 set_indentation_param_emacs (CppJavaPlugin* plugin, const gchar *param,
 					   const gchar *value)
 {
-	DEBUG_PRINT ("Setting indent param: %s = %s", param, value);
+	//DEBUG_PRINT ("Setting indent param: %s = %s", param, value);
 	if (strcasecmp (param, "indent-tabs-mode") == 0)
 	{
 		if (strcasecmp (value, "t") == 0)
@@ -443,7 +449,7 @@ static void
 set_indentation_param_vim (CppJavaPlugin* plugin, const gchar *param,
 					   const gchar *value)
 {
-	DEBUG_PRINT ("Setting indent param: %s = %s", param, value);
+	//DEBUG_PRINT ("Setting indent param: %s = %s", param, value);
 	if (g_str_equal (param, "expandtab") ||
 		g_str_equal (param, "et"))
 	{
@@ -692,7 +698,7 @@ set_line_indentation (IAnjutaEditor *editor, gint line_num, gint indentation)
 		gchar *line_string = ianjuta_editor_get_text (editor, line_begin,
 														   line_end, NULL);
 		
-		DEBUG_PRINT ("line_string = '%s'", line_string);
+		//DEBUG_PRINT ("line_string = '%s'", line_string);
 		if (line_string)
 		{
 			idx = line_string;
@@ -712,7 +718,7 @@ set_line_indentation (IAnjutaEditor *editor, gint line_num, gint indentation)
 	*/
 	current_pos = ianjuta_editor_get_position (editor, NULL);
 	carat_offset = ianjuta_iterable_diff (indent_position, current_pos, NULL);
-	DEBUG_PRINT ("carat offset is = %d", carat_offset);
+	//DEBUG_PRINT ("carat offset is = %d", carat_offset);
 	
 	/* Set new indentation */
 	if (indentation > 0)
@@ -730,7 +736,7 @@ set_line_indentation (IAnjutaEditor *editor, gint line_num, gint indentation)
 					ianjuta_editor_get_text (editor, line_begin,
 												  indent_position, NULL);
 				
-				DEBUG_PRINT ("old_indent_string = '%s'", old_indent_string);
+				//DEBUG_PRINT ("old_indent_string = '%s'", old_indent_string);
 				nchars_removed = g_utf8_strlen (old_indent_string, -1);
 			}
 			
@@ -909,9 +915,8 @@ get_line_indentation_base (CppJavaPlugin *plugin,
 			} while (ianjuta_iterable_previous (new_iter, NULL));
 			if (comment)
 			{
-				ianjuta_iterable_set_position (iter,
-											   ianjuta_iterable_get_position (new_iter, NULL) - 1, 
-											   NULL);
+				ianjuta_iterable_assign (iter, new_iter, NULL);
+				ianjuta_iterable_previous (iter, NULL);
 				g_object_unref (new_iter);
 				continue;
 			}
@@ -990,9 +995,7 @@ get_line_indentation_base (CppJavaPlugin *plugin,
 						}
 						if (possible_comment)
 						{
-							ianjuta_iterable_set_position (new_iter, 
-														   ianjuta_iterable_get_position (prev, NULL),
-														   NULL);
+							ianjuta_iterable_assign (new_iter, prev, NULL);
 							g_object_unref (prev);
 							g_object_unref (next);
 							continue;
@@ -1004,9 +1007,8 @@ get_line_indentation_base (CppJavaPlugin *plugin,
 			} while (ianjuta_iterable_previous (new_iter, NULL));
 			if (comment)
 			{
-				ianjuta_iterable_set_position (iter,
-											   ianjuta_iterable_get_position (new_iter, NULL) - 1, 
-											   NULL);
+				ianjuta_iterable_assign (iter, new_iter, NULL);
+				ianjuta_iterable_previous (iter, NULL);
 				g_object_unref (new_iter);
 				continue;
 			}
@@ -1101,14 +1103,17 @@ get_line_indentation_base (CppJavaPlugin *plugin,
 			/* This is a forward reference, all lines below should have
 			 * increased indentation until the next statement has
 			 * a ':'
+			 * If current line indentation is zero, that we don't indent
 			 */
 			IAnjutaIterable* new_iter = ianjuta_iterable_clone (iter, NULL);
-			gboolean indent = FALSE;		
+			IAnjutaIterable* line_begin;
+			gboolean indent = FALSE;
+			gchar c;
 			
 			/* Is the last non-whitespace in line */
 			while (ianjuta_iterable_next (new_iter, NULL))
 			{
-				gchar c = ianjuta_editor_cell_get_char (IANJUTA_EDITOR_CELL (new_iter),
+				c = ianjuta_editor_cell_get_char (IANJUTA_EDITOR_CELL (new_iter),
 													   0, NULL);
 				if (!isspace(c))
 					break;
@@ -1118,14 +1123,23 @@ get_line_indentation_base (CppJavaPlugin *plugin,
 					break;
 				}
 			}
-			g_object_unref (new_iter);
+			line_begin = ianjuta_editor_get_line_begin_position(editor,
+																ianjuta_editor_get_line_from_position(editor, iter, NULL),
+																NULL);
+			c = ianjuta_editor_cell_get_char (IANJUTA_EDITOR_CELL (line_begin),
+														0, NULL);
 			if (indent)
 			{
 				*colon_indent = TRUE;
-				extra_indent += INDENT_SIZE;
 				if (*incomplete_statement == -1)
 					*incomplete_statement = 0;
 			}
+			if (indent && isspace(c))
+			{
+				extra_indent += INDENT_SIZE;
+			}
+			g_object_unref (new_iter);
+			g_object_unref (line_begin);
 		}	
 		else if (iter_is_newline (iter, point_ch))
 		{
@@ -1158,7 +1172,6 @@ get_line_indentation_base (CppJavaPlugin *plugin,
 	}
 	if (!line_indent && extra_indent)
 	{
-		DEBUG_PRINT ("Adding special indent");
 		line_indent += extra_indent;
 	}
 	g_object_unref (iter);
@@ -1237,9 +1250,9 @@ get_line_auto_indentation (CppJavaPlugin *plugin, IAnjutaEditor *editor,
 		/* If the last non-whitespace character in the line is ":" then
 		 * we remove the extra colon_indent
 		 */
-		end_iter = ianjuta_editor_get_line_end_position (editor, line, NULL);
 		gchar ch;
-		do
+		end_iter = ianjuta_editor_get_line_end_position (editor, line, NULL);
+		while (ianjuta_iterable_previous (end_iter, NULL))
 		{
 			ch = ianjuta_editor_cell_get_char (IANJUTA_EDITOR_CELL (end_iter),
 											   0, NULL);
@@ -1248,8 +1261,9 @@ get_line_auto_indentation (CppJavaPlugin *plugin, IAnjutaEditor *editor,
 				line_indent -= INDENT_SIZE;
 				break;
 			}
+			if (!isspace(ch) || iter_is_newline (end_iter, ch))
+				break;
 		}
-		while (isspace(ch) && ianjuta_iterable_previous (end_iter, NULL));
 		g_object_unref (end_iter);
 	}
 	
@@ -1333,74 +1347,141 @@ on_editor_char_inserted_cpp (IAnjutaEditor *editor,
 	IAnjutaEditorAttribute attrib;
 	IAnjutaIterable *iter;
 	gboolean should_auto_indent = FALSE;
-	
-	/* Do nothing if automatic indentation is not enabled */
-	if (!anjuta_preferences_get_int (plugin->prefs, PREF_INDENT_AUTOMATIC))
-		return;
-	
-	/* DEBUG_PRINT ("Char added at position %d: '%c'", insert_pos, ch); */
-	
+	static GString *stack = NULL;
+
 	iter = ianjuta_iterable_clone (insert_pos, NULL);
 	
-	if (iter_is_newline (iter, ch))
+	/* If autoindent is enabled*/
+	if (anjuta_preferences_get_int (plugin->prefs, PREF_INDENT_AUTOMATIC))
 	{
-		skip_iter_to_newline_head (iter, ch);
-		/* All newline entries means enable indenting */
-		should_auto_indent = TRUE;
-	}
-	else if (ch == '{' || ch == '}' || ch == '#')
-	{
-		/* Indent only when it's the first non-white space char in the line */
-		
-		/* Don't bother if we are inside string */
-		attrib = ianjuta_editor_cell_get_attribute (IANJUTA_EDITOR_CELL (iter),
-													NULL);
-		if (attrib != IANJUTA_EDITOR_STRING)
+	
+		/* DEBUG_PRINT ("Char added at position %d: '%c'", insert_pos, ch); */	
+	
+		if (iter_is_newline (iter, ch))
 		{
-			/* Iterate backwards till the begining of the line and disable
-			 * indenting if any non-white space char is encountered
-			 */
-			
-			/* Begin by assuming it should be indented */
+			skip_iter_to_newline_head (iter, ch);
+			/* All newline entries means enable indenting */
 			should_auto_indent = TRUE;
-			
-			while (ianjuta_iterable_previous (iter, NULL))
+		}
+		else if (ch == '{' || ch == '}' || ch == '#')
+		{
+			/* Indent only when it's the first non-white space char in the line */
+		
+			/* Don't bother if we are inside string */
+			attrib = ianjuta_editor_cell_get_attribute (IANJUTA_EDITOR_CELL (iter),
+														NULL);
+			if (attrib != IANJUTA_EDITOR_STRING)
 			{
-				ch = ianjuta_editor_cell_get_char (IANJUTA_EDITOR_CELL (iter),
-												   0, NULL);
-				
-				//DEBUG_PRINT ("Looking at char '%c'", ch);
-				
-				/* Break on begining of line (== end of previous line) */
-				if (iter_is_newline (iter, ch))
+				/* Iterate backwards till the begining of the line and disable
+				 * indenting if any non-white space char is encountered
+				 */
+			
+				/* Begin by assuming it should be indented */
+				should_auto_indent = TRUE;
+			
+				while (ianjuta_iterable_previous (iter, NULL))
 				{
-					skip_iter_to_newline_head (iter, ch);
-					break;
-				}
-				/* If a non-white space char is encountered, disabled indenting */
-				if (!isspace (ch))
-				{
-					should_auto_indent = FALSE;
-					break;
+					ch = ianjuta_editor_cell_get_char (IANJUTA_EDITOR_CELL (iter),
+													   0, NULL);
+				
+					//DEBUG_PRINT ("Looking at char '%c'", ch);
+				
+					/* Break on begining of line (== end of previous line) */
+					if (iter_is_newline (iter, ch))
+					{
+						skip_iter_to_newline_head (iter, ch);
+						break;
+					}
+					/* If a non-white space char is encountered, disabled indenting */
+					if (!isspace (ch))
+					{
+						should_auto_indent = FALSE;
+						break;
+					}
 				}
 			}
 		}
-	}
-	else if (ch == ':')
-	{
-		should_auto_indent = TRUE;
-	}
-	if (should_auto_indent)
-	{
-		gint insert_line;
-		gint line_indent;
+		if (should_auto_indent)
+		{
+			gint insert_line;
+			gint line_indent;
 		
-		ianjuta_document_begin_undo_action (IANJUTA_DOCUMENT(editor), NULL);
-		initialize_indentation_params (plugin);
-		insert_line = ianjuta_editor_get_lineno (editor, NULL);
-		line_indent = get_line_auto_indentation (plugin, editor, insert_line);
-		set_line_indentation (editor, insert_line, line_indent);
-		ianjuta_document_end_undo_action (IANJUTA_DOCUMENT(editor), NULL);
+			ianjuta_document_begin_undo_action (IANJUTA_DOCUMENT(editor), NULL);
+			initialize_indentation_params (plugin);
+			insert_line = ianjuta_editor_get_lineno (editor, NULL);
+			line_indent = get_line_auto_indentation (plugin, editor, insert_line);
+			set_line_indentation (editor, insert_line, line_indent);
+			ianjuta_document_end_undo_action (IANJUTA_DOCUMENT(editor), NULL);
+		}
+	}
+	
+	if (anjuta_preferences_get_int (plugin->prefs, PREF_BRACE_AUTOCOMPLETION))
+	{
+		if (!stack)
+			stack = g_string_new ("");
+	
+		if (ch == '[' || ch == '(')
+		{
+			ianjuta_iterable_next (iter, NULL);
+		
+			switch (ch)
+			{
+				case '[': ianjuta_editor_insert (editor, iter,
+												 "]", 1, NULL);
+						  g_string_prepend_c (stack, ']');
+						  break;
+				case '(': ianjuta_editor_insert (editor, iter,
+												 ")", 1, NULL);
+						  g_string_prepend_c (stack, ')');
+						  break;
+				default: break;
+			}
+
+			ianjuta_iterable_previous (iter, NULL);
+			ianjuta_editor_goto_position (editor, iter, NULL);
+		}
+		else if (ch == ']' || ch == ')' || ch == '"')
+		{
+			gchar *str = stack->str;
+			gchar *next_char;
+			IAnjutaIterable *end;
+
+			/* First iter*/
+			ianjuta_iterable_next (iter, NULL);
+		
+			/*
+			 * If the character is " we have to decide if we need insert
+			 * another " or we have to skip the character
+			 */
+			if (ch == '"' && *str != '"')
+			{
+				ianjuta_editor_insert (editor, iter,
+									 "\"", 1, NULL);
+				g_string_prepend_c (stack, '"');
+			
+				ianjuta_iterable_previous (iter, NULL);
+				ianjuta_editor_goto_position (editor, iter, NULL);
+				g_object_unref (iter);
+				return;
+			}
+		
+			/* End iter*/
+			end = ianjuta_iterable_clone (iter, NULL);
+			ianjuta_iterable_next (end, NULL);
+		
+			next_char = ianjuta_editor_get_text (editor, iter, end, NULL);
+		
+			if (ch == *str && ch == *next_char)
+			{
+				g_string_erase (stack, 0, 1);
+				ianjuta_editor_erase (editor, iter, end, NULL);
+			}
+			else {
+				g_string_free (stack, TRUE);
+				stack = g_string_new ("");
+			}
+			g_object_unref (end);
+		}
 	}
 	g_object_unref (iter);
 }
@@ -1582,6 +1663,117 @@ on_value_removed_current_editor (AnjutaPlugin *plugin, const gchar *name,
 	lang_plugin->current_editor = NULL;
 }
 
+const gchar* SOURCE_EXT[] =
+{
+	".c",
+	".cc",
+	".C",
+	".cpp",
+	".cxx",
+	".ccg",
+	NULL
+};
+
+const gchar* HEADER_EXT[] =
+{
+	".h",
+	".hh",
+	".H",
+	".hpp",
+	".hxx",
+	".hg",
+	NULL
+};
+
+static void
+on_swap_activate (GtkAction* action, gpointer data)
+{
+	GFile* file;
+	GFile* parent;
+	gchar* parent_uri;
+	gchar* basename;
+	gchar* ext;
+	CppJavaPlugin *lang_plugin = ANJUTA_PLUGIN_CPP_JAVA (data);
+	IAnjutaDocumentManager* docman =
+		anjuta_shell_get_interface (ANJUTA_PLUGIN(lang_plugin)->shell,
+									IAnjutaDocumentManager,
+									NULL);
+	if (!lang_plugin->current_editor || !docman)
+		return;
+	
+	file = ianjuta_file_get_file (IANJUTA_FILE (lang_plugin->current_editor),
+								  NULL);
+	parent = g_file_get_parent (file);
+	parent_uri = g_file_get_uri (parent);
+	basename = g_file_get_basename (file);
+	g_object_unref (file);
+	g_object_unref (parent);
+	ext = strstr (basename, ".");
+	if (ext)
+	{
+		int i;
+		for (i = 0; SOURCE_EXT[i] != NULL; i++)
+		{
+			if (g_str_equal (ext, SOURCE_EXT[i]))
+			{
+				int j;
+				for (j = 0; HEADER_EXT[j] != NULL; j++)
+				{
+					gchar* filename;
+					gchar* uri;
+					GFile* new_file;
+					*ext = '\0';
+					filename = g_strdup_printf ("%s%s", basename, HEADER_EXT[j]);
+					uri = g_build_filename (parent_uri, filename, NULL);
+					new_file = g_file_new_for_uri (uri);
+					g_free (uri);
+					g_free(filename);
+					if (g_file_query_exists (new_file, NULL))
+					{
+						ianjuta_document_manager_goto_file_line (docman,
+																 new_file,
+																 -1,
+																 NULL);
+						g_object_unref (new_file);
+						break;
+					}
+					g_object_unref (new_file);
+				}
+				break;
+			}
+			if (g_str_equal (ext, HEADER_EXT[i]))
+			{
+				int j;
+				for (j = 0; SOURCE_EXT[j] != NULL; j++)
+				{
+					gchar* filename;
+					gchar* uri;
+					GFile* new_file;
+					*ext = '\0';
+					filename = g_strdup_printf ("%s%s", basename, SOURCE_EXT[j]);
+					uri = g_build_filename (parent_uri, filename, NULL);
+					new_file = g_file_new_for_uri (uri);
+					g_free (uri);
+					g_free(filename);
+					if (g_file_query_exists (new_file, NULL))
+					{
+						ianjuta_document_manager_goto_file_line (docman,
+																 new_file,
+																 -1,
+																 NULL);
+						g_object_unref (new_file);
+						break;
+					}
+					g_object_unref (new_file);
+				}
+				break;
+			}
+		}
+	}
+	g_free(basename);
+	g_free (parent_uri);
+}
+
 static void
 on_auto_indent (GtkAction *action, gpointer data)
 {
@@ -1655,6 +1847,12 @@ static GtkActionEntry actions[] = {
 		N_("Auto Indent"), "<control>i",
 		N_("Auto indent current line or selection based on indentation settings"),
 		G_CALLBACK (on_auto_indent)
+	},
+	{   "ActionFileSwap", 
+		ANJUTA_STOCK_SWAP, 
+		N_("Swap .h/.c"), NULL,
+		N_("Swap c header and source files"),
+		G_CALLBACK (on_swap_activate)
 	}
 };
 
@@ -1669,6 +1867,7 @@ register_stock_icons (AnjutaPlugin *plugin)
 
 	/* Register stock icons */
 	BEGIN_REGISTER_ICON (plugin);
+	REGISTER_ICON_FULL (ANJUTA_PIXMAP_SWAP, ANJUTA_STOCK_SWAP);
 	REGISTER_ICON_FULL (ANJUTA_PIXMAP_COMPLETE, ANJUTA_STOCK_COMPLETE);	
 	REGISTER_ICON_FULL (ANJUTA_PIXMAP_AUTOCOMPLETE, ANJUTA_STOCK_AUTOCOMPLETE);
 	REGISTER_ICON_FULL (ANJUTA_PIXMAP_AUTOINDENT, ANJUTA_STOCK_AUTOINDENT);
@@ -1704,7 +1903,7 @@ cpp_java_plugin_activate_plugin (AnjutaPlugin *plugin)
 	
 	lang_plugin->editor_watch_id = 
 		anjuta_plugin_add_watch (plugin,
-								 "document_manager_current_editor",
+								  IANJUTA_DOCUMENT_MANAGER_CURRENT_DOCUMENT,
 								 on_value_added_current_editor,
 								 on_value_removed_current_editor,
 								 plugin);
@@ -1739,14 +1938,14 @@ cpp_java_plugin_finalize (GObject *obj)
 	/* CppJavaPlugin* plugin = ANJUTA_PLUGIN_CPP_JAVA (obj); */
 
 	/* Finalization codes here */
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (obj));
+	G_OBJECT_CLASS (parent_class)->finalize (obj);
 }
 
 static void
 cpp_java_plugin_dispose (GObject *obj)
 {
 	/* Disposition codes */
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, dispose, (obj));
+	G_OBJECT_CLASS (parent_class)->dispose (obj);
 }
 
 static void
