@@ -423,10 +423,12 @@ on_select_other_target_button_clicked (GtkButton *button,
 									   GtkTreeView *targets_list_view)
 {
 	GtkTreeModel *model;
+	GtkWidget *target_chooser_dialog;
 	GtkTreeIter iter;
 	gchar *selected_target_path;
 	gchar *selected_target_uri;
-	GtkWidget *target_chooser_dialog;
+	GtkTreeSelection *selection;
+	GtkTreePath *new_target_path;
 	
 	model = gtk_tree_view_get_model (targets_list_view);
 	target_chooser_dialog = gtk_file_chooser_dialog_new ("Select Target",
@@ -442,14 +444,21 @@ on_select_other_target_button_clicked (GtkButton *button,
 	{
 		selected_target_path = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (target_chooser_dialog));
 		selected_target_uri = gnome_vfs_get_uri_from_local_path (selected_target_path);
+		selection = gtk_tree_view_get_selection (targets_list_view);
 		
 		gtk_list_store_append (GTK_LIST_STORE (model), &iter);
 		gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, 
 							selected_target_path, 1,
 							selected_target_uri, -1);
 		
+		gtk_tree_selection_select_iter (selection, &iter);
+		new_target_path = gtk_tree_model_get_path (model, &iter);
+		gtk_tree_view_scroll_to_cell (targets_list_view, new_target_path, NULL,
+									  TRUE, 0.5, 0.0);
+		
 		g_free (selected_target_path);
 		g_free (selected_target_uri);
+		gtk_tree_path_free (new_target_path);
 	}
 	
 	gtk_widget_destroy (target_chooser_dialog);
@@ -754,19 +763,12 @@ static GtkActionEntry actions_file[] = {
 	}
 };
 
-#define REGISTER_ICON(icon, stock_id) \
-	pixbuf = gdk_pixbuf_new_from_file (PACKAGE_PIXMAPS_DIR"/"icon, NULL); \
-	icon_set = gtk_icon_set_new_from_pixbuf (pixbuf); \
-	gtk_icon_factory_add (icon_factory, stock_id, icon_set); \
-	g_object_unref (pixbuf);
-
 static void
 register_stock_icons (AnjutaPlugin *plugin)
 {
 	AnjutaUI *ui;
 	GtkIconFactory *icon_factory;
 	GtkIconSet *icon_set;
-	GdkPixbuf *pixbuf;
 	static gboolean registered = FALSE;
 
 	if (registered)
@@ -847,7 +849,7 @@ profiler_activate (AnjutaPlugin *plugin)
 							 ANJUTA_SHELL_PLACEMENT_CENTER,
 							 NULL);
 							 
-	profiler->project_watch_id = anjuta_plugin_add_watch (plugin, "project_root_uri", 
+	profiler->project_watch_id = anjuta_plugin_add_watch (plugin, IANJUTA_PROJECT_MANAGER_PROJECT_ROOT_URI, 
 										 				  project_root_added, 
 										 				  project_root_removed, NULL);
 										 				  
@@ -909,14 +911,14 @@ static void
 profiler_finalize (GObject *obj)
 {
 	/* Finalization codes here */
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (obj));
+	G_OBJECT_CLASS (parent_class)->finalize (obj);
 }
 
 static void
 profiler_dispose (GObject *obj)
 {
 	/* Disposition codes */
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, dispose, (obj));
+	G_OBJECT_CLASS (parent_class)->dispose (obj);
 }
 
 static void
@@ -946,22 +948,34 @@ profiler_class_init (GObjectClass *klass)
 
 /* File open interface */
 static void
-ifile_open (IAnjutaFile *manager, const gchar *uri,
+ifile_open (IAnjutaFile *manager, GFile* file,
 			GError **err)
 {
 	Profiler *profiler;
 	
 	profiler = PROFILER (manager);
 	
+	gchar* uri = g_file_get_uri (file);
+	
 	profiler_set_target (profiler, uri);
 	
+	/* Respect user settings for this target if they exist. Otherwise, don't
+	 * create an entry for this target to avoid having the settings file 
+	 * balloon with the settings for a bunch of targets, espcially if this 
+	 * is a one-time operation. If previous settings don't exist, just use
+	 * the defaults. */
+	if (gprof_options_has_target (profiler->options,  uri))
+		gprof_options_set_target (profiler->options, uri);
+	else
+		gprof_options_set_target (profiler->options, NULL);
+	
 	if (profiler_get_data (profiler))
 		gprof_view_manager_refresh_views (profiler->view_manager);
-	
+	g_free (file);
 }
 
-static gchar*
-ifile_get_uri (IAnjutaFile *manager, GError **err)
+static GFile*
+ifile_get_file (IAnjutaFile *manager, GError **err)
 {
 	DEBUG_PRINT ("Unsupported operation");
 	return NULL;
@@ -971,7 +985,7 @@ static void
 ifile_iface_init (IAnjutaFileIface *iface)
 {
 	iface->open = ifile_open;
-	iface->get_uri = ifile_get_uri;
+	iface->get_file = ifile_get_file;
 }
 
 ANJUTA_PLUGIN_BEGIN (Profiler, profiler);
