@@ -1,13 +1,13 @@
 [+ autogen5 template +]
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
 /*
- * main.c
+ * main.cc
  * Copyright (C) [+Author+] [+(shell "date +%Y")+] <[+Email+]>
  * 
 [+CASE (get "License") +]
-[+ == "BSD"  +][+(bsd  "main.cpp" (get "Author") " * ")+]
-[+ == "LGPL" +][+(lgpl "main.cpp" (get "Author") " * ")+]
-[+ == "GPL"  +][+(gpl  "main.cpp"                " * ")+]
+[+ == "BSD"  +][+(bsd  "main.cc" (get "Author") " * ")+]
+[+ == "LGPL" +][+(lgpl "main.cc" (get "Author") " * ")+]
+[+ == "GPL"  +][+(gpl  "main.cc"                " * ")+]
 [+ESAC+] */
 
 #include <iostream>
