@@ -98,7 +98,7 @@ assist_tip_set_tips (AssistTip* tip, GList* tips)
 		g_free(text);
 		text = new_text;
 	}
-	tip_text = g_strdup_printf("<tt>%s</tt>", text);
+	tip_text = g_markup_printf_escaped ("<tt>%s</tt>", text);
 	gtk_label_set_markup(GTK_LABEL(tip->label), tip_text);
 	gtk_widget_show (tip->label);
 	g_free(text);
@@ -158,10 +158,6 @@ assist_tip_move(AssistTip* assist_tip, GtkTextView* text_view, int offset)
 	int x,y;
 	assist_tip_get_coordinates(GTK_WIDGET(text_view), offset, &x, &y, assist_tip->label);	
 	gtk_window_move(GTK_WINDOW(assist_tip), x, y);
-	/* Make it slightly transparent */
-#if (GTK_MAJOR_VERSION > 2 || (GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION >= 12))
-	gtk_window_set_opacity (GTK_WINDOW (assist_tip), 0.85);
-#endif
 
 }
 
@@ -195,6 +191,6 @@ assist_tip_new (GtkTextView* view, GList* tips)
 	
 	/* Position is off by one for '(' brace */
 	assist_tip->position--;
-	
+										
 	return GTK_WIDGET(object);
 }
