@@ -22,6 +22,7 @@
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <libanjuta/anjuta-shell.h>
 #include <libanjuta/anjuta-debug.h>
+#include <libanjuta/anjuta-utils.h>
 #include <libanjuta/interfaces/ianjuta-help.h>
 #include <libanjuta/interfaces/ianjuta-document-manager.h>
 #include <libanjuta/interfaces/ianjuta-project-manager.h>
@@ -80,7 +81,7 @@ register_stock_icons (AnjutaPlugin *plugin)
 static void
 goto_file_line (AnjutaPlugin *plugin, const gchar *filename, gint lineno)
 {
-	gchar *uri;
+	GFile* file;
 	IAnjutaDocumentManager *docman;
 	
 	g_return_if_fail (filename != NULL);
@@ -89,9 +90,9 @@ goto_file_line (AnjutaPlugin *plugin, const gchar *filename, gint lineno)
 	docman = anjuta_shell_get_interface (plugin->shell, IAnjutaDocumentManager,
 										 NULL);
 		
-	uri = gnome_vfs_get_uri_from_local_path (filename);
-	ianjuta_document_manager_goto_uri_line (docman, uri, lineno, NULL);
-	g_free (uri);
+	file = g_file_new_for_path (filename);
+	ianjuta_document_manager_goto_file_line (docman, file, lineno, NULL);
+	g_object_unref (file);
 }
 
 static void
@@ -351,7 +352,7 @@ on_project_element_removed (IAnjutaProjectManager *pm, const gchar *uri,
 	}
 }
 
-#define LOCAL_TAGS_DIR ".anjuta/tags"
+#define LOCAL_TAGS_SUBDIR "tags/"
 
 // add a new project
 static void
@@ -362,7 +363,6 @@ project_root_added (AnjutaPlugin *plugin, const gchar *name,
 	IAnjutaProjectManager *pm;
 	SymbolBrowserPlugin *sv_plugin;
 	const gchar *root_uri;
-	gchar* tags;
 
 	sv_plugin = ANJUTA_PLUGIN_SYMBOL_BROWSER (plugin);
 	  
@@ -400,18 +400,23 @@ project_root_added (AnjutaPlugin *plugin, const gchar *name,
 	/* Load from project */
 	if (anjuta_preferences_get_int (sv_plugin->prefs,
 											"symbol_browser.tags_auto_load"))
-	{
-		gchar* dirname = g_build_filename (g_get_home_dir (), LOCAL_TAGS_DIR, NULL);
+	{		
+		gchar* pref_symbols = anjuta_preferences_get (sv_plugin->prefs, SYMBOL_BROWSER_TAGS);
+		gchar* dirname = anjuta_util_get_user_cache_file_path (LOCAL_TAGS_SUBDIR,NULL);
 		GList* packages = ianjuta_project_manager_get_packages (pm, NULL);
 		GList* node;
-		GString* str = g_string_new ("");
+		GString* str = g_string_new (pref_symbols);
+		g_free (pref_symbols);
 		for (node = packages; node != NULL; node = g_list_next (node))
 		{
 			gchar* pathname = g_build_filename (dirname, node->data, NULL);
-			if (str->len)
-				g_string_append_c (str, ':');
-			g_string_append (str, pathname);
-			g_string_append (str, ".anjutatags.gz");
+			if (!strstr (str->str, pathname))
+			{
+				if (str->len)
+					g_string_append_c (str, ':');
+				g_string_append (str, pathname);
+				g_string_append (str, ".anjutatags.gz");
+			}
 			g_free (pathname);
 		}
 		g_list_foreach (packages, (GFunc) g_free, NULL);
@@ -419,7 +424,6 @@ project_root_added (AnjutaPlugin *plugin, const gchar *name,
 		anjuta_preferences_set (sv_plugin->prefs, SYMBOL_BROWSER_TAGS, str->str);
 		g_string_free (str, TRUE);
 		g_free (dirname);
-		symbol_browser_load_global_tags (plugin);
 	}
 }	   
 
@@ -447,10 +451,12 @@ project_root_removed (AnjutaPlugin *plugin, const gchar *name,
 										  sv_plugin);
 	
 	/* clear anjuta_symbol_search side */
-	anjuta_symbol_search_clear(ANJUTA_SYMBOL_SEARCH(sv_plugin->ss));
+	if (sv_plugin->ss)
+		anjuta_symbol_search_clear(ANJUTA_SYMBOL_SEARCH(sv_plugin->ss));
 
 	/* clear glist's sfiles */
-	anjuta_symbol_view_clear (ANJUTA_SYMBOL_VIEW (sv_plugin->sv_tree));
+	if (sv_plugin->sv_tree)
+		anjuta_symbol_view_clear (ANJUTA_SYMBOL_VIEW (sv_plugin->sv_tree));
 
 	g_free (sv_plugin->project_root_uri);
 	sv_plugin->project_root_uri = NULL;
@@ -623,26 +629,30 @@ on_editor_destroy (SymbolBrowserPlugin *sv_plugin, IAnjutaEditor *editor)
 }
 
 static void
-on_editor_saved (IAnjutaEditor *editor, const gchar *saved_uri,
+on_editor_saved (IAnjutaEditor *editor, GFile* file,
 				 SymbolBrowserPlugin *sv_plugin)
 {
 	const gchar *old_uri;
 	gboolean tags_update;
 	GtkTreeModel *file_symbol_model;
-	GtkAction *action;
 	AnjutaUI *ui;
 	
 	/* FIXME: Do this only if automatic tags update is enabled */
 	/* tags_update =
 		anjuta_preferences_get_int (te->preferences, AUTOMATIC_TAGS_UPDATE);
 	*/
+	
+	if (!file)
+		return;
+	
 	tags_update = TRUE;
 	if (tags_update)
 	{
 		gchar *local_filename;
+		gchar *saved_uri = g_file_get_uri (file);
 		
 		/* Verify that it's local file */
-		local_filename = gnome_vfs_get_local_path_from_uri (saved_uri);
+		local_filename = g_file_get_path (file);
 		g_return_if_fail (local_filename != NULL);
 		g_free (local_filename);
 		
@@ -672,6 +682,7 @@ on_editor_saved (IAnjutaEditor *editor, const gchar *saved_uri,
 								 file_symbol_model);
 		sv_plugin->locals_line_number = 0;
 		on_editor_update_ui (editor, sv_plugin);
+		g_free (saved_uri);
 
 #if 0
 		/* FIXME: Re-hilite all editors on tags update */
@@ -721,18 +732,20 @@ update_editor_symbol_model (SymbolBrowserPlugin *sv_plugin)
 {
 	AnjutaUI *ui;
 	gchar *uri;
+	GFile* file;
 	GObject *editor = sv_plugin->current_editor;
 	
 	if (!editor)
 		return;
 	
 	ui = anjuta_shell_get_ui (ANJUTA_PLUGIN (sv_plugin)->shell, NULL);
-	uri = ianjuta_file_get_uri (IANJUTA_FILE (editor), NULL);
+	file = ianjuta_file_get_file (IANJUTA_FILE (editor), NULL);
+	uri = g_file_get_uri (file);
+	g_object_unref (file);
 	if (uri)
 	{
 		gchar *local_filename;
 		GtkTreeModel *file_symbol_model;
-		GtkAction *action;
 		
 		/* Verify that it's local file */
 		local_filename = gnome_vfs_get_local_path_from_uri (uri);
@@ -814,6 +827,7 @@ value_added_current_editor (AnjutaPlugin *plugin, const char *name,
 	gchar *uri;
 	GObject *editor;
 	SymbolBrowserPlugin *sv_plugin;
+	GFile* file;
 	
 	editor = g_value_get_object (value);
 	
@@ -832,7 +846,10 @@ value_added_current_editor (AnjutaPlugin *plugin, const char *name,
 	
 	update_editor_symbol_model (sv_plugin);
 	
-	uri = ianjuta_file_get_uri (IANJUTA_FILE (editor), NULL);
+	file = ianjuta_file_get_file (IANJUTA_FILE (editor), NULL);
+	uri = file ? g_file_get_uri (file) : NULL;
+	if (file)
+		g_object_unref (file);
 	if (g_hash_table_lookup (sv_plugin->editor_connected, editor) == NULL)
 	{
 		g_object_weak_ref (G_OBJECT (editor),
@@ -863,7 +880,6 @@ value_removed_current_editor (AnjutaPlugin *plugin,
 {
 	AnjutaUI *ui;
 	SymbolBrowserPlugin *sv_plugin;
-	GtkAction *action;
 
 	/* let's remove the timeout for symbols refresh */
 	
@@ -990,11 +1006,11 @@ activate_plugin (AnjutaPlugin *plugin)
 	
 	/* set up project directory watch */
 	sv_plugin->root_watch_id = anjuta_plugin_add_watch (plugin,
-									"project_root_uri",
+									IANJUTA_PROJECT_MANAGER_PROJECT_ROOT_URI,
 									project_root_added,
 									project_root_removed, NULL);
 	sv_plugin->editor_watch_id = 
-		anjuta_plugin_add_watch (plugin, "document_manager_current_editor",
+		anjuta_plugin_add_watch (plugin, IANJUTA_DOCUMENT_MANAGER_CURRENT_DOCUMENT,
 								 value_added_current_editor,
 								 value_removed_current_editor, NULL);
 	return TRUE;
@@ -1115,7 +1131,8 @@ isymbol_manager_search (IAnjutaSymbolManager *sm,
 						IAnjutaSymbolField info_fields,
 						const gchar *match_name,
 						gboolean partial_name_match,
-						gboolean global_search,
+						gboolean global_symbols_search,
+						gboolean global_tags_search, /* unused */
 						gint results_limit, /* unused */
 						gint results_offset, /* unused */
 						GError **err)
@@ -1130,7 +1147,7 @@ isymbol_manager_search (IAnjutaSymbolManager *sm,
 		name = NULL;
 	
 	tags_array = tm_workspace_find (name, match_types, NULL,
-									partial_name_match, global_search);
+									partial_name_match, global_symbols_search);
 	if (tags_array && tags_array->len)
 	{
 		iter = anjuta_symbol_iter_new (tags_array);
@@ -1141,7 +1158,7 @@ isymbol_manager_search (IAnjutaSymbolManager *sm,
 
 static IAnjutaIterable*
 isymbol_manager_get_members (IAnjutaSymbolManager *sm,
-							 IAnjutaSymbol *symbol, 
+							 const IAnjutaSymbol *symbol, 
 							 IAnjutaSymbolField info_fields,
 							 gboolean global_search,
 							 GError **err)
@@ -1166,7 +1183,7 @@ isymbol_manager_get_members (IAnjutaSymbolManager *sm,
 
 static IAnjutaIterable*
 isymbol_manager_get_class_parents (IAnjutaSymbolManager *sm,
-							 IAnjutaSymbol *symbol,
+							 const IAnjutaSymbol *symbol,
 							 IAnjutaSymbolField info_fields,
 							 GError **err)
 {
@@ -1185,12 +1202,59 @@ isymbol_manager_get_class_parents (IAnjutaSymbolManager *sm,
 	return NULL;
 }
 
+static IAnjutaIterable*
+isymbol_manager_get_scope (IAnjutaSymbolManager *sm,
+						   const gchar* filename,  
+						   gulong line,  
+						   IAnjutaSymbolField info_fields, 
+						   GError **err)
+{
+	DEBUG_PRINT ("isymbol_manager_get_scope (): not implemented");
+	return NULL;
+}
+
+static IAnjutaIterable*
+isymbol_manager_get_parent_scope (IAnjutaSymbolManager *sm,
+								  const IAnjutaSymbol *symbol, 
+								  const gchar *filename, 
+								  IAnjutaSymbolField info_fields,
+								  GError **err)
+{
+	DEBUG_PRINT ("isymbol_manager_get_parent_scope (): not implemented");
+	return NULL;	
+}
+
+
+static IAnjutaIterable*
+isymbol_manager_get_symbol_more_info (IAnjutaSymbolManager *sm,
+								  const IAnjutaSymbol *symbol, 
+								  IAnjutaSymbolField info_fields,
+								  GError **err)
+{
+	DEBUG_PRINT ("isymbol_manager_get_symbol_more_info (): not implemented");
+	return NULL;
+}
+
+static IAnjutaSymbol*
+isymbol_manager_get_symbol_by_id (IAnjutaSymbolManager *sm,
+								  gint symbol_id, 
+								  IAnjutaSymbolField info_fields,
+								  GError **err)
+{
+	DEBUG_PRINT ("isymbol_manager_get_symbol_by_id  (): not implemented");
+	return NULL;	
+}
+
 static void
 isymbol_manager_iface_init (IAnjutaSymbolManagerIface *iface)
 {
 	iface->search = isymbol_manager_search;
 	iface->get_members = isymbol_manager_get_members;
 	iface->get_class_parents = isymbol_manager_get_class_parents;
+	iface->get_scope = isymbol_manager_get_scope;
+	iface->get_parent_scope = isymbol_manager_get_parent_scope;
+	iface->get_symbol_more_info = isymbol_manager_get_symbol_more_info;
+	iface->get_symbol_by_id = isymbol_manager_get_symbol_by_id;
 }
 
 static void
