@@ -28,7 +28,7 @@
 #include <glib-object.h>
 #include <gtk/gtk.h>
 #include "symbol-db-engine.h"
-#include "plugin.h"
+
 
 G_BEGIN_DECLS
 
@@ -62,7 +62,7 @@ symbol_db_view_new (void);
 /* return the pixbufs. It will initialize pixbufs first if they weren't before
  * node_access: can be NULL.
  */
-const GdkPixbuf*
+inline const GdkPixbuf*
 symbol_db_view_get_pixbuf  (const gchar *node_type, const gchar *node_access);
 
 void 
@@ -70,12 +70,26 @@ symbol_db_view_open (SymbolDBView *dbv, SymbolDBEngine *dbe);
 
 void
 symbol_db_view_row_expanded (SymbolDBView *dbv, SymbolDBEngine *dbe, 
-							 GtkTreeIter *iter);
+							 GtkTreeIter *expanded_iter);
+
+void
+symbol_db_view_row_collapsed (SymbolDBView *dbv, SymbolDBEngine *dbe, 
+							 GtkTreeIter *expanded_iter);
 
 gboolean
 symbol_db_view_get_file_and_line (SymbolDBView *dbv, SymbolDBEngine *dbe,
 							GtkTreeIter * iter, gint *OUT_line, gchar **OUT_file);
 
+void
+symbol_db_view_recv_signals_from_engine (SymbolDBView *dbv, SymbolDBEngine *dbe,
+										 gboolean enable_status);
+
+/**
+ * Clear cache.
+ */
+void 
+symbol_db_view_clear_cache (SymbolDBView *dbv);
+
 G_END_DECLS
 
 #endif /* _SYMBOL_DB_VIEW_H_ */
